// Code generated by go generate; DO NOT EDIT.
// This file was generated by zlint-gtld-update.

/*
 * ZLint Copyright 2023 Regents of the University of Michigan
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package util

var tldMap = map[string]GTLDPeriod{
	"aaa": {
		GTLD:           "aaa",
		DelegationDate: "2015-08-28",
		RemovalDate:    "",
	},
	"aarp": {
		GTLD:           "aarp",
		DelegationDate: "2015-11-03",
		RemovalDate:    "",
	},
	"abarth": {
		GTLD:           "abarth",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"abb": {
		GTLD:           "abb",
		DelegationDate: "2015-04-25",
		RemovalDate:    "",
	},
	"abbott": {
		GTLD:           "abbott",
		DelegationDate: "2015-03-07",
		RemovalDate:    "",
	},
	"abbvie": {
		GTLD:           "abbvie",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"abc": {
		GTLD:           "abc",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"able": {
		GTLD:           "able",
		DelegationDate: "2016-06-21",
		RemovalDate:    "",
	},
	"abogado": {
		GTLD:           "abogado",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"abudhabi": {
		GTLD:           "abudhabi",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"ac": {
		GTLD:           "ac",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"academy": {
		GTLD:           "academy",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"accenture": {
		GTLD:           "accenture",
		DelegationDate: "2015-05-09",
		RemovalDate:    "",
	},
	"accountant": {
		GTLD:           "accountant",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"accountants": {
		GTLD:           "accountants",
		DelegationDate: "2014-05-07",
		RemovalDate:    "",
	},
	"aco": {
		GTLD:           "aco",
		DelegationDate: "2015-08-27",
		RemovalDate:    "",
	},
	"active": {
		GTLD:           "active",
		DelegationDate: "2014-06-26",
		RemovalDate:    "2019-02-17",
	},
	"actor": {
		GTLD:           "actor",
		DelegationDate: "2014-02-26",
		RemovalDate:    "",
	},
	"ad": {
		GTLD:           "ad",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"adac": {
		GTLD:           "adac",
		DelegationDate: "2016-01-26",
		RemovalDate:    "",
	},
	"ads": {
		GTLD:           "ads",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"adult": {
		GTLD:           "adult",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"ae": {
		GTLD:           "ae",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"aeg": {
		GTLD:           "aeg",
		DelegationDate: "2015-06-20",
		RemovalDate:    "",
	},
	"aero": {
		GTLD:           "aero",
		DelegationDate: "2002-03-02",
		RemovalDate:    "",
	},
	"aetna": {
		GTLD:           "aetna",
		DelegationDate: "2016-05-20",
		RemovalDate:    "",
	},
	"af": {
		GTLD:           "af",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"afamilycompany": {
		GTLD:           "afamilycompany",
		DelegationDate: "2016-07-31",
		RemovalDate:    "2021-12-03",
	},
	"afl": {
		GTLD:           "afl",
		DelegationDate: "2015-03-28",
		RemovalDate:    "",
	},
	"africa": {
		GTLD:           "africa",
		DelegationDate: "2017-02-15",
		RemovalDate:    "",
	},
	"ag": {
		GTLD:           "ag",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"agakhan": {
		GTLD:           "agakhan",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"agency": {
		GTLD:           "agency",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"ai": {
		GTLD:           "ai",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"aig": {
		GTLD:           "aig",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"aigo": {
		GTLD:           "aigo",
		DelegationDate: "2016-08-16",
		RemovalDate:    "2020-06-26",
	},
	"airbus": {
		GTLD:           "airbus",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"airforce": {
		GTLD:           "airforce",
		DelegationDate: "2014-04-30",
		RemovalDate:    "",
	},
	"airtel": {
		GTLD:           "airtel",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"akdn": {
		GTLD:           "akdn",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"al": {
		GTLD:           "al",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"alfaromeo": {
		GTLD:           "alfaromeo",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"alibaba": {
		GTLD:           "alibaba",
		DelegationDate: "2016-01-16",
		RemovalDate:    "",
	},
	"alipay": {
		GTLD:           "alipay",
		DelegationDate: "2016-01-16",
		RemovalDate:    "",
	},
	"allfinanz": {
		GTLD:           "allfinanz",
		DelegationDate: "2014-10-01",
		RemovalDate:    "",
	},
	"allstate": {
		GTLD:           "allstate",
		DelegationDate: "2016-07-14",
		RemovalDate:    "",
	},
	"ally": {
		GTLD:           "ally",
		DelegationDate: "2016-03-24",
		RemovalDate:    "",
	},
	"alsace": {
		GTLD:           "alsace",
		DelegationDate: "2014-10-04",
		RemovalDate:    "",
	},
	"alstom": {
		GTLD:           "alstom",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"am": {
		GTLD:           "am",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"amazon": {
		GTLD:           "amazon",
		DelegationDate: "2020-06-02",
		RemovalDate:    "",
	},
	"americanexpress": {
		GTLD:           "americanexpress",
		DelegationDate: "2016-08-08",
		RemovalDate:    "",
	},
	"americanfamily": {
		GTLD:           "americanfamily",
		DelegationDate: "2016-07-26",
		RemovalDate:    "",
	},
	"amex": {
		GTLD:           "amex",
		DelegationDate: "2016-08-08",
		RemovalDate:    "",
	},
	"amfam": {
		GTLD:           "amfam",
		DelegationDate: "2016-07-23",
		RemovalDate:    "",
	},
	"amica": {
		GTLD:           "amica",
		DelegationDate: "2015-08-29",
		RemovalDate:    "",
	},
	"amsterdam": {
		GTLD:           "amsterdam",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"analytics": {
		GTLD:           "analytics",
		DelegationDate: "2015-12-21",
		RemovalDate:    "",
	},
	"android": {
		GTLD:           "android",
		DelegationDate: "2014-11-12",
		RemovalDate:    "",
	},
	"anquan": {
		GTLD:           "anquan",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"anz": {
		GTLD:           "anz",
		DelegationDate: "2016-06-21",
		RemovalDate:    "",
	},
	"ao": {
		GTLD:           "ao",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"aol": {
		GTLD:           "aol",
		DelegationDate: "2016-11-04",
		RemovalDate:    "",
	},
	"apartments": {
		GTLD:           "apartments",
		DelegationDate: "2015-02-10",
		RemovalDate:    "",
	},
	"app": {
		GTLD:           "app",
		DelegationDate: "2015-07-02",
		RemovalDate:    "",
	},
	"apple": {
		GTLD:           "apple",
		DelegationDate: "2015-11-03",
		RemovalDate:    "",
	},
	"aq": {
		GTLD:           "aq",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"aquarelle": {
		GTLD:           "aquarelle",
		DelegationDate: "2014-12-02",
		RemovalDate:    "",
	},
	"ar": {
		GTLD:           "ar",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"arab": {
		GTLD:           "arab",
		DelegationDate: "2017-05-23",
		RemovalDate:    "",
	},
	"aramco": {
		GTLD:           "aramco",
		DelegationDate: "2015-10-15",
		RemovalDate:    "",
	},
	"archi": {
		GTLD:           "archi",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"army": {
		GTLD:           "army",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"arpa": {
		GTLD:           "arpa",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"art": {
		GTLD:           "art",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"arte": {
		GTLD:           "arte",
		DelegationDate: "2015-10-20",
		RemovalDate:    "",
	},
	"as": {
		GTLD:           "as",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"asda": {
		GTLD:           "asda",
		DelegationDate: "2016-08-14",
		RemovalDate:    "",
	},
	"asia": {
		GTLD:           "asia",
		DelegationDate: "2007-05-02",
		RemovalDate:    "",
	},
	"associates": {
		GTLD:           "associates",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"at": {
		GTLD:           "at",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"athleta": {
		GTLD:           "athleta",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"attorney": {
		GTLD:           "attorney",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"au": {
		GTLD:           "au",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"auction": {
		GTLD:           "auction",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"audi": {
		GTLD:           "audi",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"audible": {
		GTLD:           "audible",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"audio": {
		GTLD:           "audio",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"auspost": {
		GTLD:           "auspost",
		DelegationDate: "2016-08-17",
		RemovalDate:    "",
	},
	"author": {
		GTLD:           "author",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"auto": {
		GTLD:           "auto",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"autos": {
		GTLD:           "autos",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"avianca": {
		GTLD:           "avianca",
		DelegationDate: "2016-03-09",
		RemovalDate:    "",
	},
	"aw": {
		GTLD:           "aw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"aws": {
		GTLD:           "aws",
		DelegationDate: "2016-03-25",
		RemovalDate:    "",
	},
	"ax": {
		GTLD:           "ax",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"axa": {
		GTLD:           "axa",
		DelegationDate: "2014-03-19",
		RemovalDate:    "",
	},
	"az": {
		GTLD:           "az",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"azure": {
		GTLD:           "azure",
		DelegationDate: "2015-06-06",
		RemovalDate:    "",
	},
	"ba": {
		GTLD:           "ba",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"baby": {
		GTLD:           "baby",
		DelegationDate: "2016-04-08",
		RemovalDate:    "",
	},
	"baidu": {
		GTLD:           "baidu",
		DelegationDate: "2016-01-05",
		RemovalDate:    "",
	},
	"banamex": {
		GTLD:           "banamex",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"bananarepublic": {
		GTLD:           "bananarepublic",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"band": {
		GTLD:           "band",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"bank": {
		GTLD:           "bank",
		DelegationDate: "2015-01-09",
		RemovalDate:    "",
	},
	"bar": {
		GTLD:           "bar",
		DelegationDate: "2014-02-27",
		RemovalDate:    "",
	},
	"barcelona": {
		GTLD:           "barcelona",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"barclaycard": {
		GTLD:           "barclaycard",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"barclays": {
		GTLD:           "barclays",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"barefoot": {
		GTLD:           "barefoot",
		DelegationDate: "2016-03-24",
		RemovalDate:    "",
	},
	"bargains": {
		GTLD:           "bargains",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"baseball": {
		GTLD:           "baseball",
		DelegationDate: "2016-10-30",
		RemovalDate:    "",
	},
	"basketball": {
		GTLD:           "basketball",
		DelegationDate: "2016-10-19",
		RemovalDate:    "",
	},
	"bauhaus": {
		GTLD:           "bauhaus",
		DelegationDate: "2015-04-05",
		RemovalDate:    "",
	},
	"bayern": {
		GTLD:           "bayern",
		DelegationDate: "2014-05-03",
		RemovalDate:    "",
	},
	"bb": {
		GTLD:           "bb",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bbc": {
		GTLD:           "bbc",
		DelegationDate: "2015-03-21",
		RemovalDate:    "",
	},
	"bbt": {
		GTLD:           "bbt",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"bbva": {
		GTLD:           "bbva",
		DelegationDate: "2015-05-27",
		RemovalDate:    "",
	},
	"bcg": {
		GTLD:           "bcg",
		DelegationDate: "2016-03-09",
		RemovalDate:    "",
	},
	"bcn": {
		GTLD:           "bcn",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"bd": {
		GTLD:           "bd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"be": {
		GTLD:           "be",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"beats": {
		GTLD:           "beats",
		DelegationDate: "2015-11-03",
		RemovalDate:    "",
	},
	"beauty": {
		GTLD:           "beauty",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"beer": {
		GTLD:           "beer",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"bentley": {
		GTLD:           "bentley",
		DelegationDate: "2015-07-09",
		RemovalDate:    "",
	},
	"berlin": {
		GTLD:           "berlin",
		DelegationDate: "2014-01-08",
		RemovalDate:    "",
	},
	"best": {
		GTLD:           "best",
		DelegationDate: "2014-02-27",
		RemovalDate:    "",
	},
	"bestbuy": {
		GTLD:           "bestbuy",
		DelegationDate: "2016-07-19",
		RemovalDate:    "",
	},
	"bet": {
		GTLD:           "bet",
		DelegationDate: "2015-07-24",
		RemovalDate:    "",
	},
	"bf": {
		GTLD:           "bf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bg": {
		GTLD:           "bg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bh": {
		GTLD:           "bh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bharti": {
		GTLD:           "bharti",
		DelegationDate: "2015-06-14",
		RemovalDate:    "",
	},
	"bi": {
		GTLD:           "bi",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bible": {
		GTLD:           "bible",
		DelegationDate: "2015-06-02",
		RemovalDate:    "",
	},
	"bid": {
		GTLD:           "bid",
		DelegationDate: "2014-03-02",
		RemovalDate:    "",
	},
	"bike": {
		GTLD:           "bike",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"bing": {
		GTLD:           "bing",
		DelegationDate: "2015-06-10",
		RemovalDate:    "",
	},
	"bingo": {
		GTLD:           "bingo",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"bio": {
		GTLD:           "bio",
		DelegationDate: "2014-06-02",
		RemovalDate:    "",
	},
	"biz": {
		GTLD:           "biz",
		DelegationDate: "2001-09-25",
		RemovalDate:    "",
	},
	"bj": {
		GTLD:           "bj",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"black": {
		GTLD:           "black",
		DelegationDate: "2014-03-27",
		RemovalDate:    "",
	},
	"blackfriday": {
		GTLD:           "blackfriday",
		DelegationDate: "2014-04-22",
		RemovalDate:    "",
	},
	"blanco": {
		GTLD:           "blanco",
		DelegationDate: "2016-06-21",
		RemovalDate:    "2019-02-13",
	},
	"blockbuster": {
		GTLD:           "blockbuster",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"blog": {
		GTLD:           "blog",
		DelegationDate: "2016-05-18",
		RemovalDate:    "",
	},
	"bloomberg": {
		GTLD:           "bloomberg",
		DelegationDate: "2014-11-05",
		RemovalDate:    "",
	},
	"blue": {
		GTLD:           "blue",
		DelegationDate: "2014-02-05",
		RemovalDate:    "",
	},
	"bm": {
		GTLD:           "bm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bms": {
		GTLD:           "bms",
		DelegationDate: "2015-09-22",
		RemovalDate:    "",
	},
	"bmw": {
		GTLD:           "bmw",
		DelegationDate: "2014-06-21",
		RemovalDate:    "",
	},
	"bn": {
		GTLD:           "bn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bnl": {
		GTLD:           "bnl",
		DelegationDate: "2015-06-26",
		RemovalDate:    "2019-07-30",
	},
	"bnpparibas": {
		GTLD:           "bnpparibas",
		DelegationDate: "2014-08-14",
		RemovalDate:    "",
	},
	"bo": {
		GTLD:           "bo",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"boats": {
		GTLD:           "boats",
		DelegationDate: "2015-02-25",
		RemovalDate:    "",
	},
	"boehringer": {
		GTLD:           "boehringer",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"bofa": {
		GTLD:           "bofa",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"bom": {
		GTLD:           "bom",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"bond": {
		GTLD:           "bond",
		DelegationDate: "2015-03-27",
		RemovalDate:    "",
	},
	"boo": {
		GTLD:           "boo",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"book": {
		GTLD:           "book",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"booking": {
		GTLD:           "booking",
		DelegationDate: "2016-07-23",
		RemovalDate:    "",
	},
	"boots": {
		GTLD:           "boots",
		DelegationDate: "2015-08-05",
		RemovalDate:    "2018-04-06",
	},
	"bosch": {
		GTLD:           "bosch",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"bostik": {
		GTLD:           "bostik",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"boston": {
		GTLD:           "boston",
		DelegationDate: "2016-11-29",
		RemovalDate:    "",
	},
	"bot": {
		GTLD:           "bot",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"boutique": {
		GTLD:           "boutique",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"box": {
		GTLD:           "box",
		DelegationDate: "2016-11-11",
		RemovalDate:    "",
	},
	"br": {
		GTLD:           "br",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bradesco": {
		GTLD:           "bradesco",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"bridgestone": {
		GTLD:           "bridgestone",
		DelegationDate: "2015-05-01",
		RemovalDate:    "",
	},
	"broadway": {
		GTLD:           "broadway",
		DelegationDate: "2015-11-18",
		RemovalDate:    "",
	},
	"broker": {
		GTLD:           "broker",
		DelegationDate: "2015-04-29",
		RemovalDate:    "",
	},
	"brother": {
		GTLD:           "brother",
		DelegationDate: "2015-05-12",
		RemovalDate:    "",
	},
	"brussels": {
		GTLD:           "brussels",
		DelegationDate: "2014-06-18",
		RemovalDate:    "",
	},
	"bs": {
		GTLD:           "bs",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bt": {
		GTLD:           "bt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"budapest": {
		GTLD:           "budapest",
		DelegationDate: "2014-09-23",
		RemovalDate:    "2022-02-17",
	},
	"bugatti": {
		GTLD:           "bugatti",
		DelegationDate: "2015-11-25",
		RemovalDate:    "2022-10-07",
	},
	"build": {
		GTLD:           "build",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"builders": {
		GTLD:           "builders",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"business": {
		GTLD:           "business",
		DelegationDate: "2014-08-22",
		RemovalDate:    "",
	},
	"buy": {
		GTLD:           "buy",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"buzz": {
		GTLD:           "buzz",
		DelegationDate: "2013-12-18",
		RemovalDate:    "",
	},
	"bv": {
		GTLD:           "bv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bw": {
		GTLD:           "bw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"by": {
		GTLD:           "by",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bz": {
		GTLD:           "bz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"bzh": {
		GTLD:           "bzh",
		DelegationDate: "2014-06-17",
		RemovalDate:    "",
	},
	"ca": {
		GTLD:           "ca",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cab": {
		GTLD:           "cab",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"cafe": {
		GTLD:           "cafe",
		DelegationDate: "2015-04-05",
		RemovalDate:    "",
	},
	"cal": {
		GTLD:           "cal",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"call": {
		GTLD:           "call",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"calvinklein": {
		GTLD:           "calvinklein",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"cam": {
		GTLD:           "cam",
		DelegationDate: "2016-06-16",
		RemovalDate:    "",
	},
	"camera": {
		GTLD:           "camera",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"camp": {
		GTLD:           "camp",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"cancerresearch": {
		GTLD:           "cancerresearch",
		DelegationDate: "2014-07-03",
		RemovalDate:    "2022-10-05",
	},
	"canon": {
		GTLD:           "canon",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"capetown": {
		GTLD:           "capetown",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"capital": {
		GTLD:           "capital",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"capitalone": {
		GTLD:           "capitalone",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"car": {
		GTLD:           "car",
		DelegationDate: "2015-09-09",
		RemovalDate:    "",
	},
	"caravan": {
		GTLD:           "caravan",
		DelegationDate: "2014-08-15",
		RemovalDate:    "",
	},
	"cards": {
		GTLD:           "cards",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"care": {
		GTLD:           "care",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"career": {
		GTLD:           "career",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"careers": {
		GTLD:           "careers",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"cars": {
		GTLD:           "cars",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"cartier": {
		GTLD:           "cartier",
		DelegationDate: "2014-12-11",
		RemovalDate:    "2019-11-14",
	},
	"casa": {
		GTLD:           "casa",
		DelegationDate: "2014-09-23",
		RemovalDate:    "",
	},
	"case": {
		GTLD:           "case",
		DelegationDate: "2016-10-30",
		RemovalDate:    "",
	},
	"caseih": {
		GTLD:           "caseih",
		DelegationDate: "2016-10-30",
		RemovalDate:    "2021-02-19",
	},
	"cash": {
		GTLD:           "cash",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"casino": {
		GTLD:           "casino",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"cat": {
		GTLD:           "cat",
		DelegationDate: "2005-12-20",
		RemovalDate:    "",
	},
	"catering": {
		GTLD:           "catering",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"catholic": {
		GTLD:           "catholic",
		DelegationDate: "2016-12-01",
		RemovalDate:    "",
	},
	"cba": {
		GTLD:           "cba",
		DelegationDate: "2015-06-22",
		RemovalDate:    "",
	},
	"cbn": {
		GTLD:           "cbn",
		DelegationDate: "2015-02-13",
		RemovalDate:    "",
	},
	"cbre": {
		GTLD:           "cbre",
		DelegationDate: "2016-07-02",
		RemovalDate:    "",
	},
	"cbs": {
		GTLD:           "cbs",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"cc": {
		GTLD:           "cc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cd": {
		GTLD:           "cd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ceb": {
		GTLD:           "ceb",
		DelegationDate: "2015-08-08",
		RemovalDate:    "2020-12-08",
	},
	"center": {
		GTLD:           "center",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"ceo": {
		GTLD:           "ceo",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"cern": {
		GTLD:           "cern",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"cf": {
		GTLD:           "cf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cfa": {
		GTLD:           "cfa",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"cfd": {
		GTLD:           "cfd",
		DelegationDate: "2015-03-13",
		RemovalDate:    "",
	},
	"cg": {
		GTLD:           "cg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ch": {
		GTLD:           "ch",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"chanel": {
		GTLD:           "chanel",
		DelegationDate: "2015-08-05",
		RemovalDate:    "",
	},
	"channel": {
		GTLD:           "channel",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"charity": {
		GTLD:           "charity",
		DelegationDate: "2018-06-07",
		RemovalDate:    "",
	},
	"chase": {
		GTLD:           "chase",
		DelegationDate: "2016-02-27",
		RemovalDate:    "",
	},
	"chat": {
		GTLD:           "chat",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"cheap": {
		GTLD:           "cheap",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"chintai": {
		GTLD:           "chintai",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"chloe": {
		GTLD:           "chloe",
		DelegationDate: "2015-03-09",
		RemovalDate:    "2017-10-06",
	},
	"christmas": {
		GTLD:           "christmas",
		DelegationDate: "2014-02-26",
		RemovalDate:    "",
	},
	"chrome": {
		GTLD:           "chrome",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"chrysler": {
		GTLD:           "chrysler",
		DelegationDate: "2016-07-28",
		RemovalDate:    "2019-11-19",
	},
	"church": {
		GTLD:           "church",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"ci": {
		GTLD:           "ci",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cipriani": {
		GTLD:           "cipriani",
		DelegationDate: "2015-10-09",
		RemovalDate:    "",
	},
	"circle": {
		GTLD:           "circle",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"cisco": {
		GTLD:           "cisco",
		DelegationDate: "2015-05-15",
		RemovalDate:    "",
	},
	"citadel": {
		GTLD:           "citadel",
		DelegationDate: "2016-07-23",
		RemovalDate:    "",
	},
	"citi": {
		GTLD:           "citi",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"citic": {
		GTLD:           "citic",
		DelegationDate: "2014-04-29",
		RemovalDate:    "",
	},
	"city": {
		GTLD:           "city",
		DelegationDate: "2014-07-10",
		RemovalDate:    "",
	},
	"cityeats": {
		GTLD:           "cityeats",
		DelegationDate: "2015-11-10",
		RemovalDate:    "",
	},
	"ck": {
		GTLD:           "ck",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cl": {
		GTLD:           "cl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"claims": {
		GTLD:           "claims",
		DelegationDate: "2014-05-07",
		RemovalDate:    "",
	},
	"cleaning": {
		GTLD:           "cleaning",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"click": {
		GTLD:           "click",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"clinic": {
		GTLD:           "clinic",
		DelegationDate: "2014-04-22",
		RemovalDate:    "",
	},
	"clinique": {
		GTLD:           "clinique",
		DelegationDate: "2015-12-28",
		RemovalDate:    "",
	},
	"clothing": {
		GTLD:           "clothing",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"cloud": {
		GTLD:           "cloud",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"club": {
		GTLD:           "club",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"clubmed": {
		GTLD:           "clubmed",
		DelegationDate: "2015-10-02",
		RemovalDate:    "",
	},
	"cm": {
		GTLD:           "cm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cn": {
		GTLD:           "cn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"co": {
		GTLD:           "co",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"coach": {
		GTLD:           "coach",
		DelegationDate: "2014-11-26",
		RemovalDate:    "",
	},
	"codes": {
		GTLD:           "codes",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"coffee": {
		GTLD:           "coffee",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"college": {
		GTLD:           "college",
		DelegationDate: "2014-04-10",
		RemovalDate:    "",
	},
	"cologne": {
		GTLD:           "cologne",
		DelegationDate: "2014-03-19",
		RemovalDate:    "",
	},
	"com": {
		GTLD:           "com",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"comcast": {
		GTLD:           "comcast",
		DelegationDate: "2016-07-07",
		RemovalDate:    "",
	},
	"commbank": {
		GTLD:           "commbank",
		DelegationDate: "2015-06-22",
		RemovalDate:    "",
	},
	"community": {
		GTLD:           "community",
		DelegationDate: "2014-01-25",
		RemovalDate:    "",
	},
	"company": {
		GTLD:           "company",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"compare": {
		GTLD:           "compare",
		DelegationDate: "2016-01-15",
		RemovalDate:    "",
	},
	"computer": {
		GTLD:           "computer",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"comsec": {
		GTLD:           "comsec",
		DelegationDate: "2015-11-16",
		RemovalDate:    "",
	},
	"condos": {
		GTLD:           "condos",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"construction": {
		GTLD:           "construction",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"consulting": {
		GTLD:           "consulting",
		DelegationDate: "2014-04-01",
		RemovalDate:    "",
	},
	"contact": {
		GTLD:           "contact",
		DelegationDate: "2015-12-22",
		RemovalDate:    "",
	},
	"contractors": {
		GTLD:           "contractors",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"cooking": {
		GTLD:           "cooking",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"cookingchannel": {
		GTLD:           "cookingchannel",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"cool": {
		GTLD:           "cool",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"coop": {
		GTLD:           "coop",
		DelegationDate: "2001-12-20",
		RemovalDate:    "",
	},
	"corsica": {
		GTLD:           "corsica",
		DelegationDate: "2015-05-16",
		RemovalDate:    "",
	},
	"country": {
		GTLD:           "country",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"coupon": {
		GTLD:           "coupon",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"coupons": {
		GTLD:           "coupons",
		DelegationDate: "2015-05-13",
		RemovalDate:    "",
	},
	"courses": {
		GTLD:           "courses",
		DelegationDate: "2015-02-25",
		RemovalDate:    "",
	},
	"cpa": {
		GTLD:           "cpa",
		DelegationDate: "2019-09-20",
		RemovalDate:    "",
	},
	"cr": {
		GTLD:           "cr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"credit": {
		GTLD:           "credit",
		DelegationDate: "2014-05-07",
		RemovalDate:    "",
	},
	"creditcard": {
		GTLD:           "creditcard",
		DelegationDate: "2014-04-29",
		RemovalDate:    "",
	},
	"creditunion": {
		GTLD:           "creditunion",
		DelegationDate: "2015-11-10",
		RemovalDate:    "",
	},
	"cricket": {
		GTLD:           "cricket",
		DelegationDate: "2014-11-17",
		RemovalDate:    "",
	},
	"crown": {
		GTLD:           "crown",
		DelegationDate: "2015-06-19",
		RemovalDate:    "",
	},
	"crs": {
		GTLD:           "crs",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"cruise": {
		GTLD:           "cruise",
		DelegationDate: "2016-11-12",
		RemovalDate:    "",
	},
	"cruises": {
		GTLD:           "cruises",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"csc": {
		GTLD:           "csc",
		DelegationDate: "2015-09-01",
		RemovalDate:    "2022-02-01",
	},
	"cu": {
		GTLD:           "cu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cuisinella": {
		GTLD:           "cuisinella",
		DelegationDate: "2014-07-03",
		RemovalDate:    "",
	},
	"cv": {
		GTLD:           "cv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cw": {
		GTLD:           "cw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cx": {
		GTLD:           "cx",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cy": {
		GTLD:           "cy",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"cymru": {
		GTLD:           "cymru",
		DelegationDate: "2014-08-08",
		RemovalDate:    "",
	},
	"cyou": {
		GTLD:           "cyou",
		DelegationDate: "2015-04-03",
		RemovalDate:    "",
	},
	"cz": {
		GTLD:           "cz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"dabur": {
		GTLD:           "dabur",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"dad": {
		GTLD:           "dad",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"dance": {
		GTLD:           "dance",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"data": {
		GTLD:           "data",
		DelegationDate: "2016-12-20",
		RemovalDate:    "",
	},
	"date": {
		GTLD:           "date",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"dating": {
		GTLD:           "dating",
		DelegationDate: "2014-01-25",
		RemovalDate:    "",
	},
	"datsun": {
		GTLD:           "datsun",
		DelegationDate: "2015-03-04",
		RemovalDate:    "",
	},
	"day": {
		GTLD:           "day",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"dclk": {
		GTLD:           "dclk",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"dds": {
		GTLD:           "dds",
		DelegationDate: "2016-05-11",
		RemovalDate:    "",
	},
	"de": {
		GTLD:           "de",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"deal": {
		GTLD:           "deal",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"dealer": {
		GTLD:           "dealer",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"deals": {
		GTLD:           "deals",
		DelegationDate: "2014-07-10",
		RemovalDate:    "",
	},
	"degree": {
		GTLD:           "degree",
		DelegationDate: "2014-05-30",
		RemovalDate:    "",
	},
	"delivery": {
		GTLD:           "delivery",
		DelegationDate: "2014-11-01",
		RemovalDate:    "",
	},
	"dell": {
		GTLD:           "dell",
		DelegationDate: "2015-10-14",
		RemovalDate:    "",
	},
	"deloitte": {
		GTLD:           "deloitte",
		DelegationDate: "2016-01-29",
		RemovalDate:    "",
	},
	"delta": {
		GTLD:           "delta",
		DelegationDate: "2015-07-11",
		RemovalDate:    "",
	},
	"democrat": {
		GTLD:           "democrat",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"dental": {
		GTLD:           "dental",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"dentist": {
		GTLD:           "dentist",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"desi": {
		GTLD:           "desi",
		DelegationDate: "2014-04-10",
		RemovalDate:    "",
	},
	"design": {
		GTLD:           "design",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"dev": {
		GTLD:           "dev",
		DelegationDate: "2014-12-18",
		RemovalDate:    "",
	},
	"dhl": {
		GTLD:           "dhl",
		DelegationDate: "2016-06-02",
		RemovalDate:    "",
	},
	"diamonds": {
		GTLD:           "diamonds",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"diet": {
		GTLD:           "diet",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"digital": {
		GTLD:           "digital",
		DelegationDate: "2014-05-07",
		RemovalDate:    "",
	},
	"direct": {
		GTLD:           "direct",
		DelegationDate: "2014-07-02",
		RemovalDate:    "",
	},
	"directory": {
		GTLD:           "directory",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"discount": {
		GTLD:           "discount",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"discover": {
		GTLD:           "discover",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"dish": {
		GTLD:           "dish",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"diy": {
		GTLD:           "diy",
		DelegationDate: "2016-08-25",
		RemovalDate:    "",
	},
	"dj": {
		GTLD:           "dj",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"dk": {
		GTLD:           "dk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"dm": {
		GTLD:           "dm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"dnp": {
		GTLD:           "dnp",
		DelegationDate: "2014-03-11",
		RemovalDate:    "",
	},
	"do": {
		GTLD:           "do",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"docs": {
		GTLD:           "docs",
		DelegationDate: "2014-12-18",
		RemovalDate:    "",
	},
	"doctor": {
		GTLD:           "doctor",
		DelegationDate: "2016-07-21",
		RemovalDate:    "",
	},
	"dodge": {
		GTLD:           "dodge",
		DelegationDate: "2016-08-04",
		RemovalDate:    "2019-11-19",
	},
	"dog": {
		GTLD:           "dog",
		DelegationDate: "2015-04-29",
		RemovalDate:    "",
	},
	"doha": {
		GTLD:           "doha",
		DelegationDate: "2015-03-25",
		RemovalDate:    "2019-04-09",
	},
	"domains": {
		GTLD:           "domains",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"doosan": {
		GTLD:           "doosan",
		DelegationDate: "2014-12-13",
		RemovalDate:    "2016-02-24",
	},
	"dot": {
		GTLD:           "dot",
		DelegationDate: "2016-05-18",
		RemovalDate:    "",
	},
	"download": {
		GTLD:           "download",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"drive": {
		GTLD:           "drive",
		DelegationDate: "2015-06-20",
		RemovalDate:    "",
	},
	"dtv": {
		GTLD:           "dtv",
		DelegationDate: "2016-05-27",
		RemovalDate:    "",
	},
	"dubai": {
		GTLD:           "dubai",
		DelegationDate: "2016-01-07",
		RemovalDate:    "",
	},
	"duck": {
		GTLD:           "duck",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2021-12-03",
	},
	"dunlop": {
		GTLD:           "dunlop",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"duns": {
		GTLD:           "duns",
		DelegationDate: "2016-07-23",
		RemovalDate:    "2019-08-30",
	},
	"dupont": {
		GTLD:           "dupont",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"durban": {
		GTLD:           "durban",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"dvag": {
		GTLD:           "dvag",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"dvr": {
		GTLD:           "dvr",
		DelegationDate: "2016-09-30",
		RemovalDate:    "",
	},
	"dz": {
		GTLD:           "dz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"earth": {
		GTLD:           "earth",
		DelegationDate: "2015-05-14",
		RemovalDate:    "",
	},
	"eat": {
		GTLD:           "eat",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"ec": {
		GTLD:           "ec",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"eco": {
		GTLD:           "eco",
		DelegationDate: "2016-08-28",
		RemovalDate:    "",
	},
	"edeka": {
		GTLD:           "edeka",
		DelegationDate: "2016-01-21",
		RemovalDate:    "",
	},
	"edu": {
		GTLD:           "edu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"education": {
		GTLD:           "education",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"ee": {
		GTLD:           "ee",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"eg": {
		GTLD:           "eg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"email": {
		GTLD:           "email",
		DelegationDate: "2014-01-02",
		RemovalDate:    "",
	},
	"emerck": {
		GTLD:           "emerck",
		DelegationDate: "2014-10-22",
		RemovalDate:    "",
	},
	"energy": {
		GTLD:           "energy",
		DelegationDate: "2014-11-01",
		RemovalDate:    "",
	},
	"engineer": {
		GTLD:           "engineer",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"engineering": {
		GTLD:           "engineering",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"enterprises": {
		GTLD:           "enterprises",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"epost": {
		GTLD:           "epost",
		DelegationDate: "2016-06-07",
		RemovalDate:    "2019-02-15",
	},
	"epson": {
		GTLD:           "epson",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"equipment": {
		GTLD:           "equipment",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"er": {
		GTLD:           "er",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ericsson": {
		GTLD:           "ericsson",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"erni": {
		GTLD:           "erni",
		DelegationDate: "2015-03-12",
		RemovalDate:    "",
	},
	"es": {
		GTLD:           "es",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"esq": {
		GTLD:           "esq",
		DelegationDate: "2014-08-29",
		RemovalDate:    "",
	},
	"estate": {
		GTLD:           "estate",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"esurance": {
		GTLD:           "esurance",
		DelegationDate: "2016-07-23",
		RemovalDate:    "2020-05-26",
	},
	"et": {
		GTLD:           "et",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"etisalat": {
		GTLD:           "etisalat",
		DelegationDate: "2017-06-01",
		RemovalDate:    "",
	},
	"eu": {
		GTLD:           "eu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"eurovision": {
		GTLD:           "eurovision",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"eus": {
		GTLD:           "eus",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"events": {
		GTLD:           "events",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"everbank": {
		GTLD:           "everbank",
		DelegationDate: "2014-11-26",
		RemovalDate:    "2019-11-14",
	},
	"exchange": {
		GTLD:           "exchange",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"expert": {
		GTLD:           "expert",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"exposed": {
		GTLD:           "exposed",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"express": {
		GTLD:           "express",
		DelegationDate: "2015-04-05",
		RemovalDate:    "",
	},
	"extraspace": {
		GTLD:           "extraspace",
		DelegationDate: "2016-03-25",
		RemovalDate:    "",
	},
	"fage": {
		GTLD:           "fage",
		DelegationDate: "2015-08-08",
		RemovalDate:    "",
	},
	"fail": {
		GTLD:           "fail",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"fairwinds": {
		GTLD:           "fairwinds",
		DelegationDate: "2015-11-13",
		RemovalDate:    "",
	},
	"faith": {
		GTLD:           "faith",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"family": {
		GTLD:           "family",
		DelegationDate: "2015-08-11",
		RemovalDate:    "",
	},
	"fan": {
		GTLD:           "fan",
		DelegationDate: "2015-03-16",
		RemovalDate:    "",
	},
	"fans": {
		GTLD:           "fans",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"farm": {
		GTLD:           "farm",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"farmers": {
		GTLD:           "farmers",
		DelegationDate: "2016-06-25",
		RemovalDate:    "",
	},
	"fashion": {
		GTLD:           "fashion",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"fast": {
		GTLD:           "fast",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"fedex": {
		GTLD:           "fedex",
		DelegationDate: "2016-06-25",
		RemovalDate:    "",
	},
	"feedback": {
		GTLD:           "feedback",
		DelegationDate: "2014-04-10",
		RemovalDate:    "",
	},
	"ferrari": {
		GTLD:           "ferrari",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"ferrero": {
		GTLD:           "ferrero",
		DelegationDate: "2015-11-07",
		RemovalDate:    "",
	},
	"fi": {
		GTLD:           "fi",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"fiat": {
		GTLD:           "fiat",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"fidelity": {
		GTLD:           "fidelity",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"fido": {
		GTLD:           "fido",
		DelegationDate: "2016-09-20",
		RemovalDate:    "",
	},
	"film": {
		GTLD:           "film",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"final": {
		GTLD:           "final",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"finance": {
		GTLD:           "finance",
		DelegationDate: "2014-04-29",
		RemovalDate:    "",
	},
	"financial": {
		GTLD:           "financial",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"fire": {
		GTLD:           "fire",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"firestone": {
		GTLD:           "firestone",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"firmdale": {
		GTLD:           "firmdale",
		DelegationDate: "2014-11-20",
		RemovalDate:    "",
	},
	"fish": {
		GTLD:           "fish",
		DelegationDate: "2014-02-21",
		RemovalDate:    "",
	},
	"fishing": {
		GTLD:           "fishing",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"fit": {
		GTLD:           "fit",
		DelegationDate: "2015-01-09",
		RemovalDate:    "",
	},
	"fitness": {
		GTLD:           "fitness",
		DelegationDate: "2014-04-22",
		RemovalDate:    "",
	},
	"fj": {
		GTLD:           "fj",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"fk": {
		GTLD:           "fk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"flickr": {
		GTLD:           "flickr",
		DelegationDate: "2016-02-13",
		RemovalDate:    "",
	},
	"flights": {
		GTLD:           "flights",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"flir": {
		GTLD:           "flir",
		DelegationDate: "2016-05-10",
		RemovalDate:    "",
	},
	"florist": {
		GTLD:           "florist",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"flowers": {
		GTLD:           "flowers",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"flsmidth": {
		GTLD:           "flsmidth",
		DelegationDate: "2014-10-15",
		RemovalDate:    "2016-07-29",
	},
	"fly": {
		GTLD:           "fly",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"fm": {
		GTLD:           "fm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"fo": {
		GTLD:           "fo",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"foo": {
		GTLD:           "foo",
		DelegationDate: "2014-04-19",
		RemovalDate:    "",
	},
	"food": {
		GTLD:           "food",
		DelegationDate: "2016-11-10",
		RemovalDate:    "",
	},
	"foodnetwork": {
		GTLD:           "foodnetwork",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"football": {
		GTLD:           "football",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"ford": {
		GTLD:           "ford",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"forex": {
		GTLD:           "forex",
		DelegationDate: "2015-03-12",
		RemovalDate:    "",
	},
	"forsale": {
		GTLD:           "forsale",
		DelegationDate: "2014-10-01",
		RemovalDate:    "",
	},
	"forum": {
		GTLD:           "forum",
		DelegationDate: "2015-07-01",
		RemovalDate:    "",
	},
	"foundation": {
		GTLD:           "foundation",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"fox": {
		GTLD:           "fox",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"fr": {
		GTLD:           "fr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"free": {
		GTLD:           "free",
		DelegationDate: "2016-11-08",
		RemovalDate:    "",
	},
	"fresenius": {
		GTLD:           "fresenius",
		DelegationDate: "2016-01-09",
		RemovalDate:    "",
	},
	"frl": {
		GTLD:           "frl",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"frogans": {
		GTLD:           "frogans",
		DelegationDate: "2014-04-19",
		RemovalDate:    "",
	},
	"frontdoor": {
		GTLD:           "frontdoor",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"frontier": {
		GTLD:           "frontier",
		DelegationDate: "2016-02-06",
		RemovalDate:    "",
	},
	"ftr": {
		GTLD:           "ftr",
		DelegationDate: "2016-04-17",
		RemovalDate:    "",
	},
	"fujitsu": {
		GTLD:           "fujitsu",
		DelegationDate: "2016-07-07",
		RemovalDate:    "",
	},
	"fujixerox": {
		GTLD:           "fujixerox",
		DelegationDate: "2016-07-15",
		RemovalDate:    "2021-03-26",
	},
	"fun": {
		GTLD:           "fun",
		DelegationDate: "2016-12-21",
		RemovalDate:    "",
	},
	"fund": {
		GTLD:           "fund",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"furniture": {
		GTLD:           "furniture",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"futbol": {
		GTLD:           "futbol",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"fyi": {
		GTLD:           "fyi",
		DelegationDate: "2015-05-22",
		RemovalDate:    "",
	},
	"ga": {
		GTLD:           "ga",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gal": {
		GTLD:           "gal",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"gallery": {
		GTLD:           "gallery",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"gallo": {
		GTLD:           "gallo",
		DelegationDate: "2016-03-22",
		RemovalDate:    "",
	},
	"gallup": {
		GTLD:           "gallup",
		DelegationDate: "2016-02-11",
		RemovalDate:    "",
	},
	"game": {
		GTLD:           "game",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"games": {
		GTLD:           "games",
		DelegationDate: "2016-06-02",
		RemovalDate:    "",
	},
	"gap": {
		GTLD:           "gap",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"garden": {
		GTLD:           "garden",
		DelegationDate: "2014-12-13",
		RemovalDate:    "",
	},
	"gay": {
		GTLD:           "gay",
		DelegationDate: "2019-08-09",
		RemovalDate:    "",
	},
	"gb": {
		GTLD:           "gb",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gbiz": {
		GTLD:           "gbiz",
		DelegationDate: "2014-08-27",
		RemovalDate:    "",
	},
	"gd": {
		GTLD:           "gd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gdn": {
		GTLD:           "gdn",
		DelegationDate: "2015-02-13",
		RemovalDate:    "",
	},
	"ge": {
		GTLD:           "ge",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gea": {
		GTLD:           "gea",
		DelegationDate: "2015-08-28",
		RemovalDate:    "",
	},
	"gent": {
		GTLD:           "gent",
		DelegationDate: "2014-07-12",
		RemovalDate:    "",
	},
	"genting": {
		GTLD:           "genting",
		DelegationDate: "2015-06-20",
		RemovalDate:    "",
	},
	"george": {
		GTLD:           "george",
		DelegationDate: "2016-08-18",
		RemovalDate:    "",
	},
	"gf": {
		GTLD:           "gf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gg": {
		GTLD:           "gg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ggee": {
		GTLD:           "ggee",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"gh": {
		GTLD:           "gh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gi": {
		GTLD:           "gi",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gift": {
		GTLD:           "gift",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"gifts": {
		GTLD:           "gifts",
		DelegationDate: "2014-08-08",
		RemovalDate:    "",
	},
	"gives": {
		GTLD:           "gives",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"giving": {
		GTLD:           "giving",
		DelegationDate: "2015-08-06",
		RemovalDate:    "",
	},
	"gl": {
		GTLD:           "gl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"glade": {
		GTLD:           "glade",
		DelegationDate: "2016-07-28",
		RemovalDate:    "2021-12-03",
	},
	"glass": {
		GTLD:           "glass",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"gle": {
		GTLD:           "gle",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"global": {
		GTLD:           "global",
		DelegationDate: "2014-06-11",
		RemovalDate:    "",
	},
	"globo": {
		GTLD:           "globo",
		DelegationDate: "2014-05-03",
		RemovalDate:    "",
	},
	"gm": {
		GTLD:           "gm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gmail": {
		GTLD:           "gmail",
		DelegationDate: "2014-08-27",
		RemovalDate:    "",
	},
	"gmbh": {
		GTLD:           "gmbh",
		DelegationDate: "2016-03-09",
		RemovalDate:    "",
	},
	"gmo": {
		GTLD:           "gmo",
		DelegationDate: "2014-05-03",
		RemovalDate:    "",
	},
	"gmx": {
		GTLD:           "gmx",
		DelegationDate: "2014-09-05",
		RemovalDate:    "",
	},
	"gn": {
		GTLD:           "gn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"godaddy": {
		GTLD:           "godaddy",
		DelegationDate: "2016-07-07",
		RemovalDate:    "",
	},
	"gold": {
		GTLD:           "gold",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"goldpoint": {
		GTLD:           "goldpoint",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"golf": {
		GTLD:           "golf",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"goo": {
		GTLD:           "goo",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"goodhands": {
		GTLD:           "goodhands",
		DelegationDate: "2016-07-14",
		RemovalDate:    "2018-09-20",
	},
	"goodyear": {
		GTLD:           "goodyear",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"goog": {
		GTLD:           "goog",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"google": {
		GTLD:           "google",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"gop": {
		GTLD:           "gop",
		DelegationDate: "2014-04-04",
		RemovalDate:    "",
	},
	"got": {
		GTLD:           "got",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"gov": {
		GTLD:           "gov",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gp": {
		GTLD:           "gp",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gq": {
		GTLD:           "gq",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gr": {
		GTLD:           "gr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"grainger": {
		GTLD:           "grainger",
		DelegationDate: "2015-11-13",
		RemovalDate:    "",
	},
	"graphics": {
		GTLD:           "graphics",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"gratis": {
		GTLD:           "gratis",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"green": {
		GTLD:           "green",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"gripe": {
		GTLD:           "gripe",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"grocery": {
		GTLD:           "grocery",
		DelegationDate: "2017-06-28",
		RemovalDate:    "",
	},
	"group": {
		GTLD:           "group",
		DelegationDate: "2015-08-08",
		RemovalDate:    "",
	},
	"gs": {
		GTLD:           "gs",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gt": {
		GTLD:           "gt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gu": {
		GTLD:           "gu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"guardian": {
		GTLD:           "guardian",
		DelegationDate: "2016-05-13",
		RemovalDate:    "",
	},
	"gucci": {
		GTLD:           "gucci",
		DelegationDate: "2015-10-27",
		RemovalDate:    "",
	},
	"guge": {
		GTLD:           "guge",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"guide": {
		GTLD:           "guide",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"guitars": {
		GTLD:           "guitars",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"guru": {
		GTLD:           "guru",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"gw": {
		GTLD:           "gw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"gy": {
		GTLD:           "gy",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hair": {
		GTLD:           "hair",
		DelegationDate: "2016-12-02",
		RemovalDate:    "",
	},
	"hamburg": {
		GTLD:           "hamburg",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"hangout": {
		GTLD:           "hangout",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"haus": {
		GTLD:           "haus",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"hbo": {
		GTLD:           "hbo",
		DelegationDate: "2016-08-14",
		RemovalDate:    "",
	},
	"hdfc": {
		GTLD:           "hdfc",
		DelegationDate: "2016-08-16",
		RemovalDate:    "",
	},
	"hdfcbank": {
		GTLD:           "hdfcbank",
		DelegationDate: "2016-02-11",
		RemovalDate:    "",
	},
	"health": {
		GTLD:           "health",
		DelegationDate: "2016-01-26",
		RemovalDate:    "",
	},
	"healthcare": {
		GTLD:           "healthcare",
		DelegationDate: "2014-07-30",
		RemovalDate:    "",
	},
	"help": {
		GTLD:           "help",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"helsinki": {
		GTLD:           "helsinki",
		DelegationDate: "2016-01-26",
		RemovalDate:    "",
	},
	"here": {
		GTLD:           "here",
		DelegationDate: "2014-08-29",
		RemovalDate:    "",
	},
	"hermes": {
		GTLD:           "hermes",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"hgtv": {
		GTLD:           "hgtv",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"hiphop": {
		GTLD:           "hiphop",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"hisamitsu": {
		GTLD:           "hisamitsu",
		DelegationDate: "2016-06-02",
		RemovalDate:    "",
	},
	"hitachi": {
		GTLD:           "hitachi",
		DelegationDate: "2015-05-01",
		RemovalDate:    "",
	},
	"hiv": {
		GTLD:           "hiv",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"hk": {
		GTLD:           "hk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hkt": {
		GTLD:           "hkt",
		DelegationDate: "2016-05-12",
		RemovalDate:    "",
	},
	"hm": {
		GTLD:           "hm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hn": {
		GTLD:           "hn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hockey": {
		GTLD:           "hockey",
		DelegationDate: "2015-05-07",
		RemovalDate:    "",
	},
	"holdings": {
		GTLD:           "holdings",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"holiday": {
		GTLD:           "holiday",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"homedepot": {
		GTLD:           "homedepot",
		DelegationDate: "2015-06-04",
		RemovalDate:    "",
	},
	"homegoods": {
		GTLD:           "homegoods",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"homes": {
		GTLD:           "homes",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"homesense": {
		GTLD:           "homesense",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"honda": {
		GTLD:           "honda",
		DelegationDate: "2015-04-30",
		RemovalDate:    "",
	},
	"honeywell": {
		GTLD:           "honeywell",
		DelegationDate: "2016-07-26",
		RemovalDate:    "2019-06-06",
	},
	"horse": {
		GTLD:           "horse",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"hospital": {
		GTLD:           "hospital",
		DelegationDate: "2016-12-09",
		RemovalDate:    "",
	},
	"host": {
		GTLD:           "host",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"hosting": {
		GTLD:           "hosting",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"hot": {
		GTLD:           "hot",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"hoteles": {
		GTLD:           "hoteles",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"hotels": {
		GTLD:           "hotels",
		DelegationDate: "2017-04-07",
		RemovalDate:    "",
	},
	"hotmail": {
		GTLD:           "hotmail",
		DelegationDate: "2015-06-10",
		RemovalDate:    "",
	},
	"house": {
		GTLD:           "house",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"how": {
		GTLD:           "how",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"hr": {
		GTLD:           "hr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hsbc": {
		GTLD:           "hsbc",
		DelegationDate: "2015-07-10",
		RemovalDate:    "",
	},
	"ht": {
		GTLD:           "ht",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"htc": {
		GTLD:           "htc",
		DelegationDate: "2016-04-02",
		RemovalDate:    "2017-10-24",
	},
	"hu": {
		GTLD:           "hu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"hughes": {
		GTLD:           "hughes",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"hyatt": {
		GTLD:           "hyatt",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"hyundai": {
		GTLD:           "hyundai",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"ibm": {
		GTLD:           "ibm",
		DelegationDate: "2014-10-01",
		RemovalDate:    "",
	},
	"icbc": {
		GTLD:           "icbc",
		DelegationDate: "2015-05-13",
		RemovalDate:    "",
	},
	"ice": {
		GTLD:           "ice",
		DelegationDate: "2015-07-22",
		RemovalDate:    "",
	},
	"icu": {
		GTLD:           "icu",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"id": {
		GTLD:           "id",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ie": {
		GTLD:           "ie",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ieee": {
		GTLD:           "ieee",
		DelegationDate: "2016-07-21",
		RemovalDate:    "",
	},
	"ifm": {
		GTLD:           "ifm",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"iinet": {
		GTLD:           "iinet",
		DelegationDate: "2015-07-09",
		RemovalDate:    "2016-12-21",
	},
	"ikano": {
		GTLD:           "ikano",
		DelegationDate: "2016-07-01",
		RemovalDate:    "",
	},
	"il": {
		GTLD:           "il",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"im": {
		GTLD:           "im",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"imamat": {
		GTLD:           "imamat",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"imdb": {
		GTLD:           "imdb",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"immo": {
		GTLD:           "immo",
		DelegationDate: "2014-08-27",
		RemovalDate:    "",
	},
	"immobilien": {
		GTLD:           "immobilien",
		DelegationDate: "2014-01-02",
		RemovalDate:    "",
	},
	"in": {
		GTLD:           "in",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"inc": {
		GTLD:           "inc",
		DelegationDate: "2018-07-17",
		RemovalDate:    "",
	},
	"industries": {
		GTLD:           "industries",
		DelegationDate: "2014-02-21",
		RemovalDate:    "",
	},
	"infiniti": {
		GTLD:           "infiniti",
		DelegationDate: "2015-03-04",
		RemovalDate:    "",
	},
	"info": {
		GTLD:           "info",
		DelegationDate: "2001-09-19",
		RemovalDate:    "",
	},
	"ing": {
		GTLD:           "ing",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"ink": {
		GTLD:           "ink",
		DelegationDate: "2014-03-11",
		RemovalDate:    "",
	},
	"institute": {
		GTLD:           "institute",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"insurance": {
		GTLD:           "insurance",
		DelegationDate: "2015-12-03",
		RemovalDate:    "",
	},
	"insure": {
		GTLD:           "insure",
		DelegationDate: "2014-04-29",
		RemovalDate:    "",
	},
	"int": {
		GTLD:           "int",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"intel": {
		GTLD:           "intel",
		DelegationDate: "2016-07-28",
		RemovalDate:    "2020-10-07",
	},
	"international": {
		GTLD:           "international",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"intuit": {
		GTLD:           "intuit",
		DelegationDate: "2016-07-12",
		RemovalDate:    "",
	},
	"investments": {
		GTLD:           "investments",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"io": {
		GTLD:           "io",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ipiranga": {
		GTLD:           "ipiranga",
		DelegationDate: "2015-07-26",
		RemovalDate:    "",
	},
	"iq": {
		GTLD:           "iq",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ir": {
		GTLD:           "ir",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"irish": {
		GTLD:           "irish",
		DelegationDate: "2014-12-02",
		RemovalDate:    "",
	},
	"is": {
		GTLD:           "is",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"iselect": {
		GTLD:           "iselect",
		DelegationDate: "2016-01-15",
		RemovalDate:    "2019-08-05",
	},
	"ismaili": {
		GTLD:           "ismaili",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"ist": {
		GTLD:           "ist",
		DelegationDate: "2015-07-11",
		RemovalDate:    "",
	},
	"istanbul": {
		GTLD:           "istanbul",
		DelegationDate: "2015-07-11",
		RemovalDate:    "",
	},
	"it": {
		GTLD:           "it",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"itau": {
		GTLD:           "itau",
		DelegationDate: "2015-07-22",
		RemovalDate:    "",
	},
	"itv": {
		GTLD:           "itv",
		DelegationDate: "2016-06-21",
		RemovalDate:    "",
	},
	"iveco": {
		GTLD:           "iveco",
		DelegationDate: "2016-10-30",
		RemovalDate:    "2021-04-21",
	},
	"iwc": {
		GTLD:           "iwc",
		DelegationDate: "2014-12-13",
		RemovalDate:    "2018-06-28",
	},
	"jaguar": {
		GTLD:           "jaguar",
		DelegationDate: "2015-10-27",
		RemovalDate:    "",
	},
	"java": {
		GTLD:           "java",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"jcb": {
		GTLD:           "jcb",
		DelegationDate: "2015-01-23",
		RemovalDate:    "",
	},
	"jcp": {
		GTLD:           "jcp",
		DelegationDate: "2016-03-30",
		RemovalDate:    "2020-11-20",
	},
	"je": {
		GTLD:           "je",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"jeep": {
		GTLD:           "jeep",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"jetzt": {
		GTLD:           "jetzt",
		DelegationDate: "2014-03-15",
		RemovalDate:    "",
	},
	"jewelry": {
		GTLD:           "jewelry",
		DelegationDate: "2015-04-16",
		RemovalDate:    "",
	},
	"jio": {
		GTLD:           "jio",
		DelegationDate: "2016-11-15",
		RemovalDate:    "",
	},
	"jlc": {
		GTLD:           "jlc",
		DelegationDate: "2015-06-10",
		RemovalDate:    "2018-09-18",
	},
	"jll": {
		GTLD:           "jll",
		DelegationDate: "2015-05-22",
		RemovalDate:    "",
	},
	"jm": {
		GTLD:           "jm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"jmp": {
		GTLD:           "jmp",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"jnj": {
		GTLD:           "jnj",
		DelegationDate: "2016-04-08",
		RemovalDate:    "",
	},
	"jo": {
		GTLD:           "jo",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"jobs": {
		GTLD:           "jobs",
		DelegationDate: "2005-09-09",
		RemovalDate:    "",
	},
	"joburg": {
		GTLD:           "joburg",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"jot": {
		GTLD:           "jot",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"joy": {
		GTLD:           "joy",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"jp": {
		GTLD:           "jp",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"jpmorgan": {
		GTLD:           "jpmorgan",
		DelegationDate: "2016-02-27",
		RemovalDate:    "",
	},
	"jprs": {
		GTLD:           "jprs",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"juegos": {
		GTLD:           "juegos",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"juniper": {
		GTLD:           "juniper",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"kaufen": {
		GTLD:           "kaufen",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"kddi": {
		GTLD:           "kddi",
		DelegationDate: "2015-01-09",
		RemovalDate:    "",
	},
	"ke": {
		GTLD:           "ke",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kerryhotels": {
		GTLD:           "kerryhotels",
		DelegationDate: "2016-03-05",
		RemovalDate:    "",
	},
	"kerrylogistics": {
		GTLD:           "kerrylogistics",
		DelegationDate: "2016-03-05",
		RemovalDate:    "",
	},
	"kerryproperties": {
		GTLD:           "kerryproperties",
		DelegationDate: "2016-03-05",
		RemovalDate:    "",
	},
	"kfh": {
		GTLD:           "kfh",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"kg": {
		GTLD:           "kg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kh": {
		GTLD:           "kh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ki": {
		GTLD:           "ki",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kia": {
		GTLD:           "kia",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"kids": {
		GTLD:           "kids",
		DelegationDate: "2022-04-04",
		RemovalDate:    "",
	},
	"kim": {
		GTLD:           "kim",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"kinder": {
		GTLD:           "kinder",
		DelegationDate: "2015-10-09",
		RemovalDate:    "",
	},
	"kindle": {
		GTLD:           "kindle",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"kitchen": {
		GTLD:           "kitchen",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"kiwi": {
		GTLD:           "kiwi",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"km": {
		GTLD:           "km",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kn": {
		GTLD:           "kn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"koeln": {
		GTLD:           "koeln",
		DelegationDate: "2014-03-05",
		RemovalDate:    "",
	},
	"komatsu": {
		GTLD:           "komatsu",
		DelegationDate: "2015-03-26",
		RemovalDate:    "",
	},
	"kosher": {
		GTLD:           "kosher",
		DelegationDate: "2016-06-10",
		RemovalDate:    "",
	},
	"kp": {
		GTLD:           "kp",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kpmg": {
		GTLD:           "kpmg",
		DelegationDate: "2016-04-05",
		RemovalDate:    "",
	},
	"kpn": {
		GTLD:           "kpn",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"kr": {
		GTLD:           "kr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"krd": {
		GTLD:           "krd",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"kred": {
		GTLD:           "kred",
		DelegationDate: "2014-02-27",
		RemovalDate:    "",
	},
	"kuokgroup": {
		GTLD:           "kuokgroup",
		DelegationDate: "2016-03-05",
		RemovalDate:    "",
	},
	"kw": {
		GTLD:           "kw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ky": {
		GTLD:           "ky",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"kyoto": {
		GTLD:           "kyoto",
		DelegationDate: "2015-01-28",
		RemovalDate:    "",
	},
	"kz": {
		GTLD:           "kz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"la": {
		GTLD:           "la",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"lacaixa": {
		GTLD:           "lacaixa",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"ladbrokes": {
		GTLD:           "ladbrokes",
		DelegationDate: "2016-07-29",
		RemovalDate:    "2019-11-19",
	},
	"lamborghini": {
		GTLD:           "lamborghini",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"lamer": {
		GTLD:           "lamer",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"lancaster": {
		GTLD:           "lancaster",
		DelegationDate: "2015-07-15",
		RemovalDate:    "",
	},
	"lancia": {
		GTLD:           "lancia",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"lancome": {
		GTLD:           "lancome",
		DelegationDate: "2016-07-15",
		RemovalDate:    "2019-11-28",
	},
	"land": {
		GTLD:           "land",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"landrover": {
		GTLD:           "landrover",
		DelegationDate: "2015-10-27",
		RemovalDate:    "",
	},
	"lanxess": {
		GTLD:           "lanxess",
		DelegationDate: "2016-01-26",
		RemovalDate:    "",
	},
	"lasalle": {
		GTLD:           "lasalle",
		DelegationDate: "2015-06-11",
		RemovalDate:    "",
	},
	"lat": {
		GTLD:           "lat",
		DelegationDate: "2015-01-09",
		RemovalDate:    "",
	},
	"latino": {
		GTLD:           "latino",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"latrobe": {
		GTLD:           "latrobe",
		DelegationDate: "2014-12-02",
		RemovalDate:    "",
	},
	"law": {
		GTLD:           "law",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"lawyer": {
		GTLD:           "lawyer",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"lb": {
		GTLD:           "lb",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"lc": {
		GTLD:           "lc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"lds": {
		GTLD:           "lds",
		DelegationDate: "2014-11-19",
		RemovalDate:    "",
	},
	"lease": {
		GTLD:           "lease",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"leclerc": {
		GTLD:           "leclerc",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"lefrak": {
		GTLD:           "lefrak",
		DelegationDate: "2016-07-14",
		RemovalDate:    "",
	},
	"legal": {
		GTLD:           "legal",
		DelegationDate: "2014-11-26",
		RemovalDate:    "",
	},
	"lego": {
		GTLD:           "lego",
		DelegationDate: "2016-06-16",
		RemovalDate:    "",
	},
	"lexus": {
		GTLD:           "lexus",
		DelegationDate: "2015-07-26",
		RemovalDate:    "",
	},
	"lgbt": {
		GTLD:           "lgbt",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"li": {
		GTLD:           "li",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"liaison": {
		GTLD:           "liaison",
		DelegationDate: "2015-05-02",
		RemovalDate:    "2020-01-04",
	},
	"lidl": {
		GTLD:           "lidl",
		DelegationDate: "2014-12-13",
		RemovalDate:    "",
	},
	"life": {
		GTLD:           "life",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"lifeinsurance": {
		GTLD:           "lifeinsurance",
		DelegationDate: "2016-01-19",
		RemovalDate:    "",
	},
	"lifestyle": {
		GTLD:           "lifestyle",
		DelegationDate: "2015-11-10",
		RemovalDate:    "",
	},
	"lighting": {
		GTLD:           "lighting",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"like": {
		GTLD:           "like",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"lilly": {
		GTLD:           "lilly",
		DelegationDate: "2016-07-31",
		RemovalDate:    "",
	},
	"limited": {
		GTLD:           "limited",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"limo": {
		GTLD:           "limo",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"lincoln": {
		GTLD:           "lincoln",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"linde": {
		GTLD:           "linde",
		DelegationDate: "2015-09-16",
		RemovalDate:    "",
	},
	"link": {
		GTLD:           "link",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"lipsy": {
		GTLD:           "lipsy",
		DelegationDate: "2016-05-03",
		RemovalDate:    "",
	},
	"live": {
		GTLD:           "live",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"living": {
		GTLD:           "living",
		DelegationDate: "2015-12-28",
		RemovalDate:    "",
	},
	"lixil": {
		GTLD:           "lixil",
		DelegationDate: "2015-07-30",
		RemovalDate:    "2021-12-29",
	},
	"lk": {
		GTLD:           "lk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"llc": {
		GTLD:           "llc",
		DelegationDate: "2018-02-22",
		RemovalDate:    "",
	},
	"llp": {
		GTLD:           "llp",
		DelegationDate: "2019-12-05",
		RemovalDate:    "",
	},
	"loan": {
		GTLD:           "loan",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"loans": {
		GTLD:           "loans",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"locker": {
		GTLD:           "locker",
		DelegationDate: "2016-05-27",
		RemovalDate:    "",
	},
	"locus": {
		GTLD:           "locus",
		DelegationDate: "2016-03-09",
		RemovalDate:    "",
	},
	"loft": {
		GTLD:           "loft",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"lol": {
		GTLD:           "lol",
		DelegationDate: "2015-05-02",
		RemovalDate:    "",
	},
	"london": {
		GTLD:           "london",
		DelegationDate: "2014-03-22",
		RemovalDate:    "",
	},
	"lotte": {
		GTLD:           "lotte",
		DelegationDate: "2015-01-14",
		RemovalDate:    "",
	},
	"lotto": {
		GTLD:           "lotto",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"love": {
		GTLD:           "love",
		DelegationDate: "2015-04-02",
		RemovalDate:    "",
	},
	"lpl": {
		GTLD:           "lpl",
		DelegationDate: "2016-07-19",
		RemovalDate:    "",
	},
	"lplfinancial": {
		GTLD:           "lplfinancial",
		DelegationDate: "2016-07-19",
		RemovalDate:    "",
	},
	"lr": {
		GTLD:           "lr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ls": {
		GTLD:           "ls",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"lt": {
		GTLD:           "lt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ltd": {
		GTLD:           "ltd",
		DelegationDate: "2015-09-23",
		RemovalDate:    "",
	},
	"ltda": {
		GTLD:           "ltda",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"lu": {
		GTLD:           "lu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"lundbeck": {
		GTLD:           "lundbeck",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"lupin": {
		GTLD:           "lupin",
		DelegationDate: "2015-05-16",
		RemovalDate:    "2020-12-10",
	},
	"luxe": {
		GTLD:           "luxe",
		DelegationDate: "2014-05-15",
		RemovalDate:    "",
	},
	"luxury": {
		GTLD:           "luxury",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"lv": {
		GTLD:           "lv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ly": {
		GTLD:           "ly",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ma": {
		GTLD:           "ma",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"macys": {
		GTLD:           "macys",
		DelegationDate: "2016-07-12",
		RemovalDate:    "",
	},
	"madrid": {
		GTLD:           "madrid",
		DelegationDate: "2014-11-20",
		RemovalDate:    "",
	},
	"maif": {
		GTLD:           "maif",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"maison": {
		GTLD:           "maison",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"makeup": {
		GTLD:           "makeup",
		DelegationDate: "2016-01-15",
		RemovalDate:    "",
	},
	"man": {
		GTLD:           "man",
		DelegationDate: "2015-07-26",
		RemovalDate:    "",
	},
	"management": {
		GTLD:           "management",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"mango": {
		GTLD:           "mango",
		DelegationDate: "2014-02-16",
		RemovalDate:    "",
	},
	"map": {
		GTLD:           "map",
		DelegationDate: "2017-06-29",
		RemovalDate:    "",
	},
	"market": {
		GTLD:           "market",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"marketing": {
		GTLD:           "marketing",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"markets": {
		GTLD:           "markets",
		DelegationDate: "2015-03-12",
		RemovalDate:    "",
	},
	"marriott": {
		GTLD:           "marriott",
		DelegationDate: "2015-01-14",
		RemovalDate:    "",
	},
	"marshalls": {
		GTLD:           "marshalls",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"maserati": {
		GTLD:           "maserati",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"mattel": {
		GTLD:           "mattel",
		DelegationDate: "2016-05-28",
		RemovalDate:    "",
	},
	"mba": {
		GTLD:           "mba",
		DelegationDate: "2015-05-22",
		RemovalDate:    "",
	},
	"mc": {
		GTLD:           "mc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mcd": {
		GTLD:           "mcd",
		DelegationDate: "2016-08-08",
		RemovalDate:    "2017-08-31",
	},
	"mcdonalds": {
		GTLD:           "mcdonalds",
		DelegationDate: "2016-08-08",
		RemovalDate:    "2017-08-31",
	},
	"mckinsey": {
		GTLD:           "mckinsey",
		DelegationDate: "2016-07-31",
		RemovalDate:    "",
	},
	"md": {
		GTLD:           "md",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"me": {
		GTLD:           "me",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"med": {
		GTLD:           "med",
		DelegationDate: "2015-12-03",
		RemovalDate:    "",
	},
	"media": {
		GTLD:           "media",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"meet": {
		GTLD:           "meet",
		DelegationDate: "2014-03-27",
		RemovalDate:    "",
	},
	"melbourne": {
		GTLD:           "melbourne",
		DelegationDate: "2014-07-10",
		RemovalDate:    "",
	},
	"meme": {
		GTLD:           "meme",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"memorial": {
		GTLD:           "memorial",
		DelegationDate: "2014-11-26",
		RemovalDate:    "",
	},
	"men": {
		GTLD:           "men",
		DelegationDate: "2015-05-20",
		RemovalDate:    "",
	},
	"menu": {
		GTLD:           "menu",
		DelegationDate: "2013-11-30",
		RemovalDate:    "",
	},
	"meo": {
		GTLD:           "meo",
		DelegationDate: "2015-10-29",
		RemovalDate:    "2018-05-26",
	},
	"merckmsd": {
		GTLD:           "merckmsd",
		DelegationDate: "2017-07-10",
		RemovalDate:    "",
	},
	"metlife": {
		GTLD:           "metlife",
		DelegationDate: "2016-05-11",
		RemovalDate:    "2020-09-07",
	},
	"mg": {
		GTLD:           "mg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mh": {
		GTLD:           "mh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"miami": {
		GTLD:           "miami",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"microsoft": {
		GTLD:           "microsoft",
		DelegationDate: "2015-06-10",
		RemovalDate:    "",
	},
	"mil": {
		GTLD:           "mil",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mini": {
		GTLD:           "mini",
		DelegationDate: "2014-06-24",
		RemovalDate:    "",
	},
	"mint": {
		GTLD:           "mint",
		DelegationDate: "2016-07-12",
		RemovalDate:    "",
	},
	"mit": {
		GTLD:           "mit",
		DelegationDate: "2016-07-06",
		RemovalDate:    "",
	},
	"mitsubishi": {
		GTLD:           "mitsubishi",
		DelegationDate: "2016-07-07",
		RemovalDate:    "",
	},
	"mk": {
		GTLD:           "mk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ml": {
		GTLD:           "ml",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mlb": {
		GTLD:           "mlb",
		DelegationDate: "2016-05-25",
		RemovalDate:    "",
	},
	"mls": {
		GTLD:           "mls",
		DelegationDate: "2016-04-20",
		RemovalDate:    "",
	},
	"mm": {
		GTLD:           "mm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mma": {
		GTLD:           "mma",
		DelegationDate: "2015-03-31",
		RemovalDate:    "",
	},
	"mn": {
		GTLD:           "mn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mo": {
		GTLD:           "mo",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mobi": {
		GTLD:           "mobi",
		DelegationDate: "2005-10-20",
		RemovalDate:    "",
	},
	"mobile": {
		GTLD:           "mobile",
		DelegationDate: "2016-12-20",
		RemovalDate:    "",
	},
	"mobily": {
		GTLD:           "mobily",
		DelegationDate: "2015-12-23",
		RemovalDate:    "2019-09-09",
	},
	"moda": {
		GTLD:           "moda",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"moe": {
		GTLD:           "moe",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"moi": {
		GTLD:           "moi",
		DelegationDate: "2015-10-07",
		RemovalDate:    "",
	},
	"mom": {
		GTLD:           "mom",
		DelegationDate: "2015-08-19",
		RemovalDate:    "",
	},
	"monash": {
		GTLD:           "monash",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"money": {
		GTLD:           "money",
		DelegationDate: "2014-11-26",
		RemovalDate:    "",
	},
	"monster": {
		GTLD:           "monster",
		DelegationDate: "2016-09-14",
		RemovalDate:    "",
	},
	"montblanc": {
		GTLD:           "montblanc",
		DelegationDate: "2015-06-05",
		RemovalDate:    "2017-09-01",
	},
	"mopar": {
		GTLD:           "mopar",
		DelegationDate: "2016-08-02",
		RemovalDate:    "2019-11-19",
	},
	"mormon": {
		GTLD:           "mormon",
		DelegationDate: "2014-11-19",
		RemovalDate:    "",
	},
	"mortgage": {
		GTLD:           "mortgage",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"moscow": {
		GTLD:           "moscow",
		DelegationDate: "2014-04-24",
		RemovalDate:    "",
	},
	"moto": {
		GTLD:           "moto",
		DelegationDate: "2016-11-12",
		RemovalDate:    "",
	},
	"motorcycles": {
		GTLD:           "motorcycles",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"mov": {
		GTLD:           "mov",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"movie": {
		GTLD:           "movie",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"movistar": {
		GTLD:           "movistar",
		DelegationDate: "2015-06-26",
		RemovalDate:    "2019-12-23",
	},
	"mp": {
		GTLD:           "mp",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mq": {
		GTLD:           "mq",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mr": {
		GTLD:           "mr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ms": {
		GTLD:           "ms",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"msd": {
		GTLD:           "msd",
		DelegationDate: "2016-07-23",
		RemovalDate:    "",
	},
	"mt": {
		GTLD:           "mt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mtn": {
		GTLD:           "mtn",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"mtpc": {
		GTLD:           "mtpc",
		DelegationDate: "2015-03-04",
		RemovalDate:    "2017-05-15",
	},
	"mtr": {
		GTLD:           "mtr",
		DelegationDate: "2015-10-07",
		RemovalDate:    "",
	},
	"mu": {
		GTLD:           "mu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"museum": {
		GTLD:           "museum",
		DelegationDate: "2001-11-01",
		RemovalDate:    "",
	},
	"music": {
		GTLD:           "music",
		DelegationDate: "2021-10-29",
		RemovalDate:    "",
	},
	"mutual": {
		GTLD:           "mutual",
		DelegationDate: "2016-04-05",
		RemovalDate:    "",
	},
	"mutuelle": {
		GTLD:           "mutuelle",
		DelegationDate: "2015-10-23",
		RemovalDate:    "2016-12-21",
	},
	"mv": {
		GTLD:           "mv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mw": {
		GTLD:           "mw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mx": {
		GTLD:           "mx",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"my": {
		GTLD:           "my",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"mz": {
		GTLD:           "mz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"na": {
		GTLD:           "na",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nab": {
		GTLD:           "nab",
		DelegationDate: "2016-08-18",
		RemovalDate:    "",
	},
	"nadex": {
		GTLD:           "nadex",
		DelegationDate: "2015-05-02",
		RemovalDate:    "2020-03-27",
	},
	"nagoya": {
		GTLD:           "nagoya",
		DelegationDate: "2014-01-29",
		RemovalDate:    "",
	},
	"name": {
		GTLD:           "name",
		DelegationDate: "2002-01-04",
		RemovalDate:    "",
	},
	"nationwide": {
		GTLD:           "nationwide",
		DelegationDate: "2016-07-15",
		RemovalDate:    "2021-04-16",
	},
	"natura": {
		GTLD:           "natura",
		DelegationDate: "2016-02-11",
		RemovalDate:    "",
	},
	"navy": {
		GTLD:           "navy",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"nba": {
		GTLD:           "nba",
		DelegationDate: "2016-08-02",
		RemovalDate:    "",
	},
	"nc": {
		GTLD:           "nc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ne": {
		GTLD:           "ne",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nec": {
		GTLD:           "nec",
		DelegationDate: "2015-05-09",
		RemovalDate:    "",
	},
	"net": {
		GTLD:           "net",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"netbank": {
		GTLD:           "netbank",
		DelegationDate: "2015-06-22",
		RemovalDate:    "",
	},
	"netflix": {
		GTLD:           "netflix",
		DelegationDate: "2016-05-28",
		RemovalDate:    "",
	},
	"network": {
		GTLD:           "network",
		DelegationDate: "2014-08-22",
		RemovalDate:    "",
	},
	"neustar": {
		GTLD:           "neustar",
		DelegationDate: "2014-02-19",
		RemovalDate:    "",
	},
	"new": {
		GTLD:           "new",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"newholland": {
		GTLD:           "newholland",
		DelegationDate: "2016-10-30",
		RemovalDate:    "2021-02-19",
	},
	"news": {
		GTLD:           "news",
		DelegationDate: "2015-03-21",
		RemovalDate:    "",
	},
	"next": {
		GTLD:           "next",
		DelegationDate: "2016-05-03",
		RemovalDate:    "",
	},
	"nextdirect": {
		GTLD:           "nextdirect",
		DelegationDate: "2016-05-03",
		RemovalDate:    "",
	},
	"nexus": {
		GTLD:           "nexus",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"nf": {
		GTLD:           "nf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nfl": {
		GTLD:           "nfl",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"ng": {
		GTLD:           "ng",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ngo": {
		GTLD:           "ngo",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"nhk": {
		GTLD:           "nhk",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"ni": {
		GTLD:           "ni",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nico": {
		GTLD:           "nico",
		DelegationDate: "2015-02-10",
		RemovalDate:    "",
	},
	"nike": {
		GTLD:           "nike",
		DelegationDate: "2016-07-09",
		RemovalDate:    "",
	},
	"nikon": {
		GTLD:           "nikon",
		DelegationDate: "2016-01-28",
		RemovalDate:    "",
	},
	"ninja": {
		GTLD:           "ninja",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"nissan": {
		GTLD:           "nissan",
		DelegationDate: "2015-03-04",
		RemovalDate:    "",
	},
	"nissay": {
		GTLD:           "nissay",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"nl": {
		GTLD:           "nl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"no": {
		GTLD:           "no",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nokia": {
		GTLD:           "nokia",
		DelegationDate: "2015-07-15",
		RemovalDate:    "",
	},
	"northwesternmutual": {
		GTLD:           "northwesternmutual",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"norton": {
		GTLD:           "norton",
		DelegationDate: "2015-12-03",
		RemovalDate:    "",
	},
	"now": {
		GTLD:           "now",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"nowruz": {
		GTLD:           "nowruz",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"nowtv": {
		GTLD:           "nowtv",
		DelegationDate: "2016-05-11",
		RemovalDate:    "",
	},
	"np": {
		GTLD:           "np",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nr": {
		GTLD:           "nr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nra": {
		GTLD:           "nra",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"nrw": {
		GTLD:           "nrw",
		DelegationDate: "2014-07-11",
		RemovalDate:    "",
	},
	"ntt": {
		GTLD:           "ntt",
		DelegationDate: "2015-02-03",
		RemovalDate:    "",
	},
	"nu": {
		GTLD:           "nu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"nyc": {
		GTLD:           "nyc",
		DelegationDate: "2014-03-20",
		RemovalDate:    "",
	},
	"nz": {
		GTLD:           "nz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"obi": {
		GTLD:           "obi",
		DelegationDate: "2015-09-23",
		RemovalDate:    "",
	},
	"observer": {
		GTLD:           "observer",
		DelegationDate: "2016-09-27",
		RemovalDate:    "",
	},
	"off": {
		GTLD:           "off",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2021-12-03",
	},
	"office": {
		GTLD:           "office",
		DelegationDate: "2015-06-23",
		RemovalDate:    "",
	},
	"okinawa": {
		GTLD:           "okinawa",
		DelegationDate: "2014-03-02",
		RemovalDate:    "",
	},
	"olayan": {
		GTLD:           "olayan",
		DelegationDate: "2016-05-03",
		RemovalDate:    "",
	},
	"olayangroup": {
		GTLD:           "olayangroup",
		DelegationDate: "2016-05-06",
		RemovalDate:    "",
	},
	"oldnavy": {
		GTLD:           "oldnavy",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"ollo": {
		GTLD:           "ollo",
		DelegationDate: "2016-05-27",
		RemovalDate:    "",
	},
	"om": {
		GTLD:           "om",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"omega": {
		GTLD:           "omega",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"one": {
		GTLD:           "one",
		DelegationDate: "2015-01-22",
		RemovalDate:    "",
	},
	"ong": {
		GTLD:           "ong",
		DelegationDate: "2014-07-27",
		RemovalDate:    "",
	},
	"onl": {
		GTLD:           "onl",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"online": {
		GTLD:           "online",
		DelegationDate: "2015-03-16",
		RemovalDate:    "",
	},
	"onyourside": {
		GTLD:           "onyourside",
		DelegationDate: "2016-07-15",
		RemovalDate:    "2021-04-16",
	},
	"ooo": {
		GTLD:           "ooo",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"open": {
		GTLD:           "open",
		DelegationDate: "2016-08-08",
		RemovalDate:    "",
	},
	"oracle": {
		GTLD:           "oracle",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"orange": {
		GTLD:           "orange",
		DelegationDate: "2015-07-09",
		RemovalDate:    "",
	},
	"org": {
		GTLD:           "org",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"organic": {
		GTLD:           "organic",
		DelegationDate: "2014-06-13",
		RemovalDate:    "",
	},
	"orientexpress": {
		GTLD:           "orientexpress",
		DelegationDate: "2016-06-22",
		RemovalDate:    "2017-04-14",
	},
	"origins": {
		GTLD:           "origins",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"osaka": {
		GTLD:           "osaka",
		DelegationDate: "2014-12-13",
		RemovalDate:    "",
	},
	"otsuka": {
		GTLD:           "otsuka",
		DelegationDate: "2014-08-27",
		RemovalDate:    "",
	},
	"ott": {
		GTLD:           "ott",
		DelegationDate: "2016-05-27",
		RemovalDate:    "",
	},
	"ovh": {
		GTLD:           "ovh",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"pa": {
		GTLD:           "pa",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"page": {
		GTLD:           "page",
		DelegationDate: "2015-03-16",
		RemovalDate:    "",
	},
	"pamperedchef": {
		GTLD:           "pamperedchef",
		DelegationDate: "2016-01-21",
		RemovalDate:    "2017-09-20",
	},
	"panasonic": {
		GTLD:           "panasonic",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"panerai": {
		GTLD:           "panerai",
		DelegationDate: "2015-03-25",
		RemovalDate:    "2018-09-18",
	},
	"paris": {
		GTLD:           "paris",
		DelegationDate: "2014-04-19",
		RemovalDate:    "",
	},
	"pars": {
		GTLD:           "pars",
		DelegationDate: "2015-12-07",
		RemovalDate:    "",
	},
	"partners": {
		GTLD:           "partners",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"parts": {
		GTLD:           "parts",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"party": {
		GTLD:           "party",
		DelegationDate: "2014-11-17",
		RemovalDate:    "",
	},
	"passagens": {
		GTLD:           "passagens",
		DelegationDate: "2016-03-02",
		RemovalDate:    "",
	},
	"pay": {
		GTLD:           "pay",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"pccw": {
		GTLD:           "pccw",
		DelegationDate: "2016-05-11",
		RemovalDate:    "",
	},
	"pe": {
		GTLD:           "pe",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pet": {
		GTLD:           "pet",
		DelegationDate: "2015-07-26",
		RemovalDate:    "",
	},
	"pf": {
		GTLD:           "pf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pfizer": {
		GTLD:           "pfizer",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"pg": {
		GTLD:           "pg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ph": {
		GTLD:           "ph",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pharmacy": {
		GTLD:           "pharmacy",
		DelegationDate: "2014-09-05",
		RemovalDate:    "",
	},
	"phd": {
		GTLD:           "phd",
		DelegationDate: "2017-06-29",
		RemovalDate:    "",
	},
	"philips": {
		GTLD:           "philips",
		DelegationDate: "2015-05-09",
		RemovalDate:    "",
	},
	"phone": {
		GTLD:           "phone",
		DelegationDate: "2016-12-20",
		RemovalDate:    "",
	},
	"photo": {
		GTLD:           "photo",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"photography": {
		GTLD:           "photography",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"photos": {
		GTLD:           "photos",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"physio": {
		GTLD:           "physio",
		DelegationDate: "2014-06-19",
		RemovalDate:    "",
	},
	"piaget": {
		GTLD:           "piaget",
		DelegationDate: "2015-03-16",
		RemovalDate:    "2019-11-14",
	},
	"pics": {
		GTLD:           "pics",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"pictet": {
		GTLD:           "pictet",
		DelegationDate: "2015-03-07",
		RemovalDate:    "",
	},
	"pictures": {
		GTLD:           "pictures",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"pid": {
		GTLD:           "pid",
		DelegationDate: "2015-12-22",
		RemovalDate:    "",
	},
	"pin": {
		GTLD:           "pin",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"ping": {
		GTLD:           "ping",
		DelegationDate: "2015-10-29",
		RemovalDate:    "",
	},
	"pink": {
		GTLD:           "pink",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"pioneer": {
		GTLD:           "pioneer",
		DelegationDate: "2016-06-02",
		RemovalDate:    "",
	},
	"pizza": {
		GTLD:           "pizza",
		DelegationDate: "2014-08-27",
		RemovalDate:    "",
	},
	"pk": {
		GTLD:           "pk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pl": {
		GTLD:           "pl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"place": {
		GTLD:           "place",
		DelegationDate: "2014-07-02",
		RemovalDate:    "",
	},
	"play": {
		GTLD:           "play",
		DelegationDate: "2015-06-20",
		RemovalDate:    "",
	},
	"playstation": {
		GTLD:           "playstation",
		DelegationDate: "2015-11-07",
		RemovalDate:    "",
	},
	"plumbing": {
		GTLD:           "plumbing",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"plus": {
		GTLD:           "plus",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"pm": {
		GTLD:           "pm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pn": {
		GTLD:           "pn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pnc": {
		GTLD:           "pnc",
		DelegationDate: "2016-07-01",
		RemovalDate:    "",
	},
	"pohl": {
		GTLD:           "pohl",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"poker": {
		GTLD:           "poker",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"politie": {
		GTLD:           "politie",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"porn": {
		GTLD:           "porn",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"post": {
		GTLD:           "post",
		DelegationDate: "2012-08-07",
		RemovalDate:    "",
	},
	"pr": {
		GTLD:           "pr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pramerica": {
		GTLD:           "pramerica",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"praxi": {
		GTLD:           "praxi",
		DelegationDate: "2014-07-22",
		RemovalDate:    "",
	},
	"press": {
		GTLD:           "press",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"prime": {
		GTLD:           "prime",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"pro": {
		GTLD:           "pro",
		DelegationDate: "2004-05-27",
		RemovalDate:    "",
	},
	"prod": {
		GTLD:           "prod",
		DelegationDate: "2014-08-29",
		RemovalDate:    "",
	},
	"productions": {
		GTLD:           "productions",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"prof": {
		GTLD:           "prof",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"progressive": {
		GTLD:           "progressive",
		DelegationDate: "2016-04-20",
		RemovalDate:    "",
	},
	"promo": {
		GTLD:           "promo",
		DelegationDate: "2015-12-31",
		RemovalDate:    "",
	},
	"properties": {
		GTLD:           "properties",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"property": {
		GTLD:           "property",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"protection": {
		GTLD:           "protection",
		DelegationDate: "2015-09-13",
		RemovalDate:    "",
	},
	"pru": {
		GTLD:           "pru",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"prudential": {
		GTLD:           "prudential",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"ps": {
		GTLD:           "ps",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pt": {
		GTLD:           "pt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pub": {
		GTLD:           "pub",
		DelegationDate: "2014-02-26",
		RemovalDate:    "",
	},
	"pw": {
		GTLD:           "pw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"pwc": {
		GTLD:           "pwc",
		DelegationDate: "2016-02-11",
		RemovalDate:    "",
	},
	"py": {
		GTLD:           "py",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"qa": {
		GTLD:           "qa",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"qpon": {
		GTLD:           "qpon",
		DelegationDate: "2014-02-12",
		RemovalDate:    "",
	},
	"quebec": {
		GTLD:           "quebec",
		DelegationDate: "2014-04-16",
		RemovalDate:    "",
	},
	"quest": {
		GTLD:           "quest",
		DelegationDate: "2016-02-06",
		RemovalDate:    "",
	},
	"qvc": {
		GTLD:           "qvc",
		DelegationDate: "2016-08-04",
		RemovalDate:    "2021-10-07",
	},
	"racing": {
		GTLD:           "racing",
		DelegationDate: "2015-04-03",
		RemovalDate:    "",
	},
	"radio": {
		GTLD:           "radio",
		DelegationDate: "2016-10-12",
		RemovalDate:    "",
	},
	"raid": {
		GTLD:           "raid",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2021-12-03",
	},
	"re": {
		GTLD:           "re",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"read": {
		GTLD:           "read",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"realestate": {
		GTLD:           "realestate",
		DelegationDate: "2016-05-23",
		RemovalDate:    "",
	},
	"realtor": {
		GTLD:           "realtor",
		DelegationDate: "2014-07-30",
		RemovalDate:    "",
	},
	"realty": {
		GTLD:           "realty",
		DelegationDate: "2015-07-01",
		RemovalDate:    "",
	},
	"recipes": {
		GTLD:           "recipes",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"red": {
		GTLD:           "red",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"redstone": {
		GTLD:           "redstone",
		DelegationDate: "2015-03-28",
		RemovalDate:    "",
	},
	"redumbrella": {
		GTLD:           "redumbrella",
		DelegationDate: "2015-12-11",
		RemovalDate:    "",
	},
	"rehab": {
		GTLD:           "rehab",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"reise": {
		GTLD:           "reise",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"reisen": {
		GTLD:           "reisen",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"reit": {
		GTLD:           "reit",
		DelegationDate: "2014-11-12",
		RemovalDate:    "",
	},
	"reliance": {
		GTLD:           "reliance",
		DelegationDate: "2016-11-15",
		RemovalDate:    "",
	},
	"ren": {
		GTLD:           "ren",
		DelegationDate: "2014-03-27",
		RemovalDate:    "",
	},
	"rent": {
		GTLD:           "rent",
		DelegationDate: "2015-04-30",
		RemovalDate:    "",
	},
	"rentals": {
		GTLD:           "rentals",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"repair": {
		GTLD:           "repair",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"report": {
		GTLD:           "report",
		DelegationDate: "2014-02-04",
		RemovalDate:    "",
	},
	"republican": {
		GTLD:           "republican",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"rest": {
		GTLD:           "rest",
		DelegationDate: "2014-04-02",
		RemovalDate:    "",
	},
	"restaurant": {
		GTLD:           "restaurant",
		DelegationDate: "2014-08-08",
		RemovalDate:    "",
	},
	"review": {
		GTLD:           "review",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"reviews": {
		GTLD:           "reviews",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"rexroth": {
		GTLD:           "rexroth",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"rich": {
		GTLD:           "rich",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"richardli": {
		GTLD:           "richardli",
		DelegationDate: "2016-05-11",
		RemovalDate:    "",
	},
	"ricoh": {
		GTLD:           "ricoh",
		DelegationDate: "2015-06-22",
		RemovalDate:    "",
	},
	"rightathome": {
		GTLD:           "rightathome",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2020-07-28",
	},
	"ril": {
		GTLD:           "ril",
		DelegationDate: "2016-11-15",
		RemovalDate:    "",
	},
	"rio": {
		GTLD:           "rio",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"rip": {
		GTLD:           "rip",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"rmit": {
		GTLD:           "rmit",
		DelegationDate: "2016-11-24",
		RemovalDate:    "2021-09-27",
	},
	"ro": {
		GTLD:           "ro",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"rocher": {
		GTLD:           "rocher",
		DelegationDate: "2015-11-07",
		RemovalDate:    "",
	},
	"rocks": {
		GTLD:           "rocks",
		DelegationDate: "2014-04-10",
		RemovalDate:    "",
	},
	"rodeo": {
		GTLD:           "rodeo",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"rogers": {
		GTLD:           "rogers",
		DelegationDate: "2016-09-20",
		RemovalDate:    "",
	},
	"room": {
		GTLD:           "room",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"rs": {
		GTLD:           "rs",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"rsvp": {
		GTLD:           "rsvp",
		DelegationDate: "2014-08-30",
		RemovalDate:    "",
	},
	"ru": {
		GTLD:           "ru",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"rugby": {
		GTLD:           "rugby",
		DelegationDate: "2017-04-07",
		RemovalDate:    "",
	},
	"ruhr": {
		GTLD:           "ruhr",
		DelegationDate: "2013-12-10",
		RemovalDate:    "",
	},
	"run": {
		GTLD:           "run",
		DelegationDate: "2015-05-07",
		RemovalDate:    "",
	},
	"rw": {
		GTLD:           "rw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"rwe": {
		GTLD:           "rwe",
		DelegationDate: "2015-10-27",
		RemovalDate:    "",
	},
	"ryukyu": {
		GTLD:           "ryukyu",
		DelegationDate: "2014-04-03",
		RemovalDate:    "",
	},
	"sa": {
		GTLD:           "sa",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"saarland": {
		GTLD:           "saarland",
		DelegationDate: "2014-04-02",
		RemovalDate:    "",
	},
	"safe": {
		GTLD:           "safe",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"safety": {
		GTLD:           "safety",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"sakura": {
		GTLD:           "sakura",
		DelegationDate: "2015-07-02",
		RemovalDate:    "",
	},
	"sale": {
		GTLD:           "sale",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"salon": {
		GTLD:           "salon",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"samsclub": {
		GTLD:           "samsclub",
		DelegationDate: "2016-08-18",
		RemovalDate:    "",
	},
	"samsung": {
		GTLD:           "samsung",
		DelegationDate: "2014-12-10",
		RemovalDate:    "",
	},
	"sandvik": {
		GTLD:           "sandvik",
		DelegationDate: "2015-05-27",
		RemovalDate:    "",
	},
	"sandvikcoromant": {
		GTLD:           "sandvikcoromant",
		DelegationDate: "2015-05-27",
		RemovalDate:    "",
	},
	"sanofi": {
		GTLD:           "sanofi",
		DelegationDate: "2015-07-24",
		RemovalDate:    "",
	},
	"sap": {
		GTLD:           "sap",
		DelegationDate: "2015-03-26",
		RemovalDate:    "",
	},
	"sapo": {
		GTLD:           "sapo",
		DelegationDate: "2015-10-29",
		RemovalDate:    "2018-05-26",
	},
	"sarl": {
		GTLD:           "sarl",
		DelegationDate: "2014-08-08",
		RemovalDate:    "",
	},
	"sas": {
		GTLD:           "sas",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"save": {
		GTLD:           "save",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"saxo": {
		GTLD:           "saxo",
		DelegationDate: "2015-02-10",
		RemovalDate:    "",
	},
	"sb": {
		GTLD:           "sb",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sbi": {
		GTLD:           "sbi",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"sbs": {
		GTLD:           "sbs",
		DelegationDate: "2015-10-29",
		RemovalDate:    "",
	},
	"sc": {
		GTLD:           "sc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sca": {
		GTLD:           "sca",
		DelegationDate: "2014-08-14",
		RemovalDate:    "",
	},
	"scb": {
		GTLD:           "scb",
		DelegationDate: "2014-07-11",
		RemovalDate:    "",
	},
	"schaeffler": {
		GTLD:           "schaeffler",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"schmidt": {
		GTLD:           "schmidt",
		DelegationDate: "2014-07-03",
		RemovalDate:    "",
	},
	"scholarships": {
		GTLD:           "scholarships",
		DelegationDate: "2015-04-02",
		RemovalDate:    "",
	},
	"school": {
		GTLD:           "school",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"schule": {
		GTLD:           "schule",
		DelegationDate: "2014-04-22",
		RemovalDate:    "",
	},
	"schwarz": {
		GTLD:           "schwarz",
		DelegationDate: "2014-12-13",
		RemovalDate:    "",
	},
	"science": {
		GTLD:           "science",
		DelegationDate: "2014-11-15",
		RemovalDate:    "",
	},
	"scjohnson": {
		GTLD:           "scjohnson",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2021-12-03",
	},
	"scor": {
		GTLD:           "scor",
		DelegationDate: "2015-06-23",
		RemovalDate:    "2020-05-27",
	},
	"scot": {
		GTLD:           "scot",
		DelegationDate: "2014-06-13",
		RemovalDate:    "",
	},
	"sd": {
		GTLD:           "sd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"se": {
		GTLD:           "se",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"search": {
		GTLD:           "search",
		DelegationDate: "2017-06-29",
		RemovalDate:    "",
	},
	"seat": {
		GTLD:           "seat",
		DelegationDate: "2015-04-18",
		RemovalDate:    "",
	},
	"secure": {
		GTLD:           "secure",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"security": {
		GTLD:           "security",
		DelegationDate: "2015-09-17",
		RemovalDate:    "",
	},
	"seek": {
		GTLD:           "seek",
		DelegationDate: "2015-08-11",
		RemovalDate:    "",
	},
	"select": {
		GTLD:           "select",
		DelegationDate: "2016-01-15",
		RemovalDate:    "",
	},
	"sener": {
		GTLD:           "sener",
		DelegationDate: "2015-05-01",
		RemovalDate:    "",
	},
	"services": {
		GTLD:           "services",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"ses": {
		GTLD:           "ses",
		DelegationDate: "2016-07-09",
		RemovalDate:    "",
	},
	"seven": {
		GTLD:           "seven",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"sew": {
		GTLD:           "sew",
		DelegationDate: "2014-12-13",
		RemovalDate:    "",
	},
	"sex": {
		GTLD:           "sex",
		DelegationDate: "2015-04-18",
		RemovalDate:    "",
	},
	"sexy": {
		GTLD:           "sexy",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"sfr": {
		GTLD:           "sfr",
		DelegationDate: "2015-12-01",
		RemovalDate:    "",
	},
	"sg": {
		GTLD:           "sg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sh": {
		GTLD:           "sh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"shangrila": {
		GTLD:           "shangrila",
		DelegationDate: "2016-07-02",
		RemovalDate:    "",
	},
	"sharp": {
		GTLD:           "sharp",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"shaw": {
		GTLD:           "shaw",
		DelegationDate: "2016-03-22",
		RemovalDate:    "",
	},
	"shell": {
		GTLD:           "shell",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"shia": {
		GTLD:           "shia",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"shiksha": {
		GTLD:           "shiksha",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"shoes": {
		GTLD:           "shoes",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"shop": {
		GTLD:           "shop",
		DelegationDate: "2016-05-23",
		RemovalDate:    "",
	},
	"shopping": {
		GTLD:           "shopping",
		DelegationDate: "2016-06-21",
		RemovalDate:    "",
	},
	"shouji": {
		GTLD:           "shouji",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"show": {
		GTLD:           "show",
		DelegationDate: "2015-04-16",
		RemovalDate:    "",
	},
	"showtime": {
		GTLD:           "showtime",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"shriram": {
		GTLD:           "shriram",
		DelegationDate: "2014-12-30",
		RemovalDate:    "2020-11-24",
	},
	"si": {
		GTLD:           "si",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"silk": {
		GTLD:           "silk",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"sina": {
		GTLD:           "sina",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"singles": {
		GTLD:           "singles",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"site": {
		GTLD:           "site",
		DelegationDate: "2015-03-16",
		RemovalDate:    "",
	},
	"sj": {
		GTLD:           "sj",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sk": {
		GTLD:           "sk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ski": {
		GTLD:           "ski",
		DelegationDate: "2015-05-30",
		RemovalDate:    "",
	},
	"skin": {
		GTLD:           "skin",
		DelegationDate: "2016-01-15",
		RemovalDate:    "",
	},
	"sky": {
		GTLD:           "sky",
		DelegationDate: "2014-12-12",
		RemovalDate:    "",
	},
	"skype": {
		GTLD:           "skype",
		DelegationDate: "2015-06-23",
		RemovalDate:    "",
	},
	"sl": {
		GTLD:           "sl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sling": {
		GTLD:           "sling",
		DelegationDate: "2016-08-10",
		RemovalDate:    "",
	},
	"sm": {
		GTLD:           "sm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"smart": {
		GTLD:           "smart",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"smile": {
		GTLD:           "smile",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"sn": {
		GTLD:           "sn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sncf": {
		GTLD:           "sncf",
		DelegationDate: "2015-06-03",
		RemovalDate:    "",
	},
	"so": {
		GTLD:           "so",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"soccer": {
		GTLD:           "soccer",
		DelegationDate: "2015-05-13",
		RemovalDate:    "",
	},
	"social": {
		GTLD:           "social",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"softbank": {
		GTLD:           "softbank",
		DelegationDate: "2016-01-16",
		RemovalDate:    "",
	},
	"software": {
		GTLD:           "software",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"sohu": {
		GTLD:           "sohu",
		DelegationDate: "2014-03-25",
		RemovalDate:    "",
	},
	"solar": {
		GTLD:           "solar",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"solutions": {
		GTLD:           "solutions",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"song": {
		GTLD:           "song",
		DelegationDate: "2016-02-24",
		RemovalDate:    "",
	},
	"sony": {
		GTLD:           "sony",
		DelegationDate: "2015-04-16",
		RemovalDate:    "",
	},
	"soy": {
		GTLD:           "soy",
		DelegationDate: "2014-04-19",
		RemovalDate:    "",
	},
	"spa": {
		GTLD:           "spa",
		DelegationDate: "2020-10-17",
		RemovalDate:    "",
	},
	"space": {
		GTLD:           "space",
		DelegationDate: "2014-05-30",
		RemovalDate:    "",
	},
	"spiegel": {
		GTLD:           "spiegel",
		DelegationDate: "2014-07-18",
		RemovalDate:    "2018-12-15",
	},
	"sport": {
		GTLD:           "sport",
		DelegationDate: "2018-01-10",
		RemovalDate:    "",
	},
	"spot": {
		GTLD:           "spot",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"spreadbetting": {
		GTLD:           "spreadbetting",
		DelegationDate: "2015-03-13",
		RemovalDate:    "2021-04-21",
	},
	"sr": {
		GTLD:           "sr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"srl": {
		GTLD:           "srl",
		DelegationDate: "2015-07-24",
		RemovalDate:    "",
	},
	"srt": {
		GTLD:           "srt",
		DelegationDate: "2016-07-28",
		RemovalDate:    "2019-11-19",
	},
	"ss": {
		GTLD:           "ss",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"st": {
		GTLD:           "st",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"stada": {
		GTLD:           "stada",
		DelegationDate: "2015-09-13",
		RemovalDate:    "",
	},
	"staples": {
		GTLD:           "staples",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"star": {
		GTLD:           "star",
		DelegationDate: "2015-12-22",
		RemovalDate:    "",
	},
	"starhub": {
		GTLD:           "starhub",
		DelegationDate: "2015-06-22",
		RemovalDate:    "2019-08-02",
	},
	"statebank": {
		GTLD:           "statebank",
		DelegationDate: "2016-04-16",
		RemovalDate:    "",
	},
	"statefarm": {
		GTLD:           "statefarm",
		DelegationDate: "2015-12-24",
		RemovalDate:    "",
	},
	"statoil": {
		GTLD:           "statoil",
		DelegationDate: "2015-06-19",
		RemovalDate:    "2018-10-03",
	},
	"stc": {
		GTLD:           "stc",
		DelegationDate: "2015-08-29",
		RemovalDate:    "",
	},
	"stcgroup": {
		GTLD:           "stcgroup",
		DelegationDate: "2015-08-28",
		RemovalDate:    "",
	},
	"stockholm": {
		GTLD:           "stockholm",
		DelegationDate: "2015-09-26",
		RemovalDate:    "",
	},
	"storage": {
		GTLD:           "storage",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"store": {
		GTLD:           "store",
		DelegationDate: "2016-02-22",
		RemovalDate:    "",
	},
	"stream": {
		GTLD:           "stream",
		DelegationDate: "2016-03-18",
		RemovalDate:    "",
	},
	"studio": {
		GTLD:           "studio",
		DelegationDate: "2015-07-08",
		RemovalDate:    "",
	},
	"study": {
		GTLD:           "study",
		DelegationDate: "2015-02-25",
		RemovalDate:    "",
	},
	"style": {
		GTLD:           "style",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"su": {
		GTLD:           "su",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sucks": {
		GTLD:           "sucks",
		DelegationDate: "2015-02-25",
		RemovalDate:    "",
	},
	"supplies": {
		GTLD:           "supplies",
		DelegationDate: "2014-02-25",
		RemovalDate:    "",
	},
	"supply": {
		GTLD:           "supply",
		DelegationDate: "2014-02-21",
		RemovalDate:    "",
	},
	"support": {
		GTLD:           "support",
		DelegationDate: "2013-12-18",
		RemovalDate:    "",
	},
	"surf": {
		GTLD:           "surf",
		DelegationDate: "2014-06-18",
		RemovalDate:    "",
	},
	"surgery": {
		GTLD:           "surgery",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"suzuki": {
		GTLD:           "suzuki",
		DelegationDate: "2014-07-02",
		RemovalDate:    "",
	},
	"sv": {
		GTLD:           "sv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"swatch": {
		GTLD:           "swatch",
		DelegationDate: "2015-06-26",
		RemovalDate:    "",
	},
	"swiftcover": {
		GTLD:           "swiftcover",
		DelegationDate: "2016-07-21",
		RemovalDate:    "2021-10-05",
	},
	"swiss": {
		GTLD:           "swiss",
		DelegationDate: "2015-04-29",
		RemovalDate:    "",
	},
	"sx": {
		GTLD:           "sx",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sy": {
		GTLD:           "sy",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"sydney": {
		GTLD:           "sydney",
		DelegationDate: "2014-11-05",
		RemovalDate:    "",
	},
	"symantec": {
		GTLD:           "symantec",
		DelegationDate: "2015-12-03",
		RemovalDate:    "2020-07-17",
	},
	"systems": {
		GTLD:           "systems",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"sz": {
		GTLD:           "sz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tab": {
		GTLD:           "tab",
		DelegationDate: "2015-11-13",
		RemovalDate:    "",
	},
	"taipei": {
		GTLD:           "taipei",
		DelegationDate: "2014-10-23",
		RemovalDate:    "",
	},
	"talk": {
		GTLD:           "talk",
		DelegationDate: "2016-03-25",
		RemovalDate:    "",
	},
	"taobao": {
		GTLD:           "taobao",
		DelegationDate: "2016-01-21",
		RemovalDate:    "",
	},
	"target": {
		GTLD:           "target",
		DelegationDate: "2016-08-04",
		RemovalDate:    "",
	},
	"tatamotors": {
		GTLD:           "tatamotors",
		DelegationDate: "2015-07-24",
		RemovalDate:    "",
	},
	"tatar": {
		GTLD:           "tatar",
		DelegationDate: "2014-08-07",
		RemovalDate:    "",
	},
	"tattoo": {
		GTLD:           "tattoo",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"tax": {
		GTLD:           "tax",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"taxi": {
		GTLD:           "taxi",
		DelegationDate: "2015-05-07",
		RemovalDate:    "",
	},
	"tc": {
		GTLD:           "tc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tci": {
		GTLD:           "tci",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"td": {
		GTLD:           "td",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tdk": {
		GTLD:           "tdk",
		DelegationDate: "2016-06-07",
		RemovalDate:    "",
	},
	"team": {
		GTLD:           "team",
		DelegationDate: "2015-04-16",
		RemovalDate:    "",
	},
	"tech": {
		GTLD:           "tech",
		DelegationDate: "2015-03-21",
		RemovalDate:    "",
	},
	"technology": {
		GTLD:           "technology",
		DelegationDate: "2013-11-14",
		RemovalDate:    "",
	},
	"tel": {
		GTLD:           "tel",
		DelegationDate: "2007-03-02",
		RemovalDate:    "",
	},
	"telecity": {
		GTLD:           "telecity",
		DelegationDate: "2016-02-25",
		RemovalDate:    "2018-08-19",
	},
	"telefonica": {
		GTLD:           "telefonica",
		DelegationDate: "2015-06-26",
		RemovalDate:    "2019-12-23",
	},
	"temasek": {
		GTLD:           "temasek",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"tennis": {
		GTLD:           "tennis",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"teva": {
		GTLD:           "teva",
		DelegationDate: "2016-04-13",
		RemovalDate:    "",
	},
	"tf": {
		GTLD:           "tf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tg": {
		GTLD:           "tg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"th": {
		GTLD:           "th",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"thd": {
		GTLD:           "thd",
		DelegationDate: "2015-05-22",
		RemovalDate:    "",
	},
	"theater": {
		GTLD:           "theater",
		DelegationDate: "2015-05-06",
		RemovalDate:    "",
	},
	"theatre": {
		GTLD:           "theatre",
		DelegationDate: "2015-09-13",
		RemovalDate:    "",
	},
	"tiaa": {
		GTLD:           "tiaa",
		DelegationDate: "2016-07-20",
		RemovalDate:    "",
	},
	"tickets": {
		GTLD:           "tickets",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"tienda": {
		GTLD:           "tienda",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"tiffany": {
		GTLD:           "tiffany",
		DelegationDate: "2016-01-21",
		RemovalDate:    "",
	},
	"tips": {
		GTLD:           "tips",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"tires": {
		GTLD:           "tires",
		DelegationDate: "2014-12-18",
		RemovalDate:    "",
	},
	"tirol": {
		GTLD:           "tirol",
		DelegationDate: "2014-06-04",
		RemovalDate:    "",
	},
	"tj": {
		GTLD:           "tj",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tjmaxx": {
		GTLD:           "tjmaxx",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"tjx": {
		GTLD:           "tjx",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"tk": {
		GTLD:           "tk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tkmaxx": {
		GTLD:           "tkmaxx",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"tl": {
		GTLD:           "tl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tm": {
		GTLD:           "tm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tmall": {
		GTLD:           "tmall",
		DelegationDate: "2016-01-21",
		RemovalDate:    "",
	},
	"tn": {
		GTLD:           "tn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"to": {
		GTLD:           "to",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"today": {
		GTLD:           "today",
		DelegationDate: "2013-11-19",
		RemovalDate:    "",
	},
	"tokyo": {
		GTLD:           "tokyo",
		DelegationDate: "2014-01-29",
		RemovalDate:    "",
	},
	"tools": {
		GTLD:           "tools",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"top": {
		GTLD:           "top",
		DelegationDate: "2014-08-03",
		RemovalDate:    "",
	},
	"toray": {
		GTLD:           "toray",
		DelegationDate: "2015-05-01",
		RemovalDate:    "",
	},
	"toshiba": {
		GTLD:           "toshiba",
		DelegationDate: "2015-02-04",
		RemovalDate:    "",
	},
	"total": {
		GTLD:           "total",
		DelegationDate: "2016-03-09",
		RemovalDate:    "",
	},
	"tours": {
		GTLD:           "tours",
		DelegationDate: "2015-03-24",
		RemovalDate:    "",
	},
	"town": {
		GTLD:           "town",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"toyota": {
		GTLD:           "toyota",
		DelegationDate: "2015-07-26",
		RemovalDate:    "",
	},
	"toys": {
		GTLD:           "toys",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"tr": {
		GTLD:           "tr",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"trade": {
		GTLD:           "trade",
		DelegationDate: "2014-03-19",
		RemovalDate:    "",
	},
	"trading": {
		GTLD:           "trading",
		DelegationDate: "2015-03-13",
		RemovalDate:    "",
	},
	"training": {
		GTLD:           "training",
		DelegationDate: "2013-12-28",
		RemovalDate:    "",
	},
	"travel": {
		GTLD:           "travel",
		DelegationDate: "2005-07-21",
		RemovalDate:    "",
	},
	"travelchannel": {
		GTLD:           "travelchannel",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"travelers": {
		GTLD:           "travelers",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"travelersinsurance": {
		GTLD:           "travelersinsurance",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"trust": {
		GTLD:           "trust",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"trv": {
		GTLD:           "trv",
		DelegationDate: "2015-12-11",
		RemovalDate:    "",
	},
	"tt": {
		GTLD:           "tt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tube": {
		GTLD:           "tube",
		DelegationDate: "2016-01-11",
		RemovalDate:    "",
	},
	"tui": {
		GTLD:           "tui",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"tunes": {
		GTLD:           "tunes",
		DelegationDate: "2016-02-25",
		RemovalDate:    "",
	},
	"tushu": {
		GTLD:           "tushu",
		DelegationDate: "2015-12-14",
		RemovalDate:    "",
	},
	"tv": {
		GTLD:           "tv",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tvs": {
		GTLD:           "tvs",
		DelegationDate: "2016-02-13",
		RemovalDate:    "",
	},
	"tw": {
		GTLD:           "tw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"tz": {
		GTLD:           "tz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ua": {
		GTLD:           "ua",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ubank": {
		GTLD:           "ubank",
		DelegationDate: "2016-08-18",
		RemovalDate:    "",
	},
	"ubs": {
		GTLD:           "ubs",
		DelegationDate: "2015-07-11",
		RemovalDate:    "",
	},
	"uconnect": {
		GTLD:           "uconnect",
		DelegationDate: "2016-07-28",
		RemovalDate:    "2019-11-19",
	},
	"ug": {
		GTLD:           "ug",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"uk": {
		GTLD:           "uk",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"unicom": {
		GTLD:           "unicom",
		DelegationDate: "2016-02-04",
		RemovalDate:    "",
	},
	"university": {
		GTLD:           "university",
		DelegationDate: "2014-04-11",
		RemovalDate:    "",
	},
	"uno": {
		GTLD:           "uno",
		DelegationDate: "2013-11-30",
		RemovalDate:    "",
	},
	"uol": {
		GTLD:           "uol",
		DelegationDate: "2014-08-16",
		RemovalDate:    "",
	},
	"ups": {
		GTLD:           "ups",
		DelegationDate: "2016-05-31",
		RemovalDate:    "",
	},
	"us": {
		GTLD:           "us",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"uy": {
		GTLD:           "uy",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"uz": {
		GTLD:           "uz",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"va": {
		GTLD:           "va",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"vacations": {
		GTLD:           "vacations",
		DelegationDate: "2014-02-21",
		RemovalDate:    "",
	},
	"vana": {
		GTLD:           "vana",
		DelegationDate: "2015-11-10",
		RemovalDate:    "",
	},
	"vanguard": {
		GTLD:           "vanguard",
		DelegationDate: "2016-08-28",
		RemovalDate:    "",
	},
	"vc": {
		GTLD:           "vc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"ve": {
		GTLD:           "ve",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"vegas": {
		GTLD:           "vegas",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"ventures": {
		GTLD:           "ventures",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"verisign": {
		GTLD:           "verisign",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"versicherung": {
		GTLD:           "versicherung",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"vet": {
		GTLD:           "vet",
		DelegationDate: "2014-05-31",
		RemovalDate:    "",
	},
	"vg": {
		GTLD:           "vg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"vi": {
		GTLD:           "vi",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"viajes": {
		GTLD:           "viajes",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"video": {
		GTLD:           "video",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"vig": {
		GTLD:           "vig",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"viking": {
		GTLD:           "viking",
		DelegationDate: "2016-02-22",
		RemovalDate:    "",
	},
	"villas": {
		GTLD:           "villas",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"vin": {
		GTLD:           "vin",
		DelegationDate: "2015-08-05",
		RemovalDate:    "",
	},
	"vip": {
		GTLD:           "vip",
		DelegationDate: "2015-11-25",
		RemovalDate:    "",
	},
	"virgin": {
		GTLD:           "virgin",
		DelegationDate: "2015-10-07",
		RemovalDate:    "",
	},
	"visa": {
		GTLD:           "visa",
		DelegationDate: "2016-07-28",
		RemovalDate:    "",
	},
	"vision": {
		GTLD:           "vision",
		DelegationDate: "2014-02-11",
		RemovalDate:    "",
	},
	"vista": {
		GTLD:           "vista",
		DelegationDate: "2015-06-22",
		RemovalDate:    "2018-09-13",
	},
	"vistaprint": {
		GTLD:           "vistaprint",
		DelegationDate: "2015-06-22",
		RemovalDate:    "2020-03-13",
	},
	"viva": {
		GTLD:           "viva",
		DelegationDate: "2015-08-28",
		RemovalDate:    "",
	},
	"vivo": {
		GTLD:           "vivo",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"vlaanderen": {
		GTLD:           "vlaanderen",
		DelegationDate: "2014-06-18",
		RemovalDate:    "",
	},
	"vn": {
		GTLD:           "vn",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"vodka": {
		GTLD:           "vodka",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"volkswagen": {
		GTLD:           "volkswagen",
		DelegationDate: "2016-01-09",
		RemovalDate:    "",
	},
	"volvo": {
		GTLD:           "volvo",
		DelegationDate: "2016-10-24",
		RemovalDate:    "",
	},
	"vote": {
		GTLD:           "vote",
		DelegationDate: "2014-03-02",
		RemovalDate:    "",
	},
	"voting": {
		GTLD:           "voting",
		DelegationDate: "2014-01-29",
		RemovalDate:    "",
	},
	"voto": {
		GTLD:           "voto",
		DelegationDate: "2014-03-02",
		RemovalDate:    "",
	},
	"voyage": {
		GTLD:           "voyage",
		DelegationDate: "2013-11-06",
		RemovalDate:    "",
	},
	"vu": {
		GTLD:           "vu",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"vuelos": {
		GTLD:           "vuelos",
		DelegationDate: "2016-03-02",
		RemovalDate:    "",
	},
	"wales": {
		GTLD:           "wales",
		DelegationDate: "2014-08-07",
		RemovalDate:    "",
	},
	"walmart": {
		GTLD:           "walmart",
		DelegationDate: "2016-08-18",
		RemovalDate:    "",
	},
	"walter": {
		GTLD:           "walter",
		DelegationDate: "2015-05-27",
		RemovalDate:    "",
	},
	"wang": {
		GTLD:           "wang",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"wanggou": {
		GTLD:           "wanggou",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"warman": {
		GTLD:           "warman",
		DelegationDate: "2016-05-03",
		RemovalDate:    "2019-11-19",
	},
	"watch": {
		GTLD:           "watch",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"watches": {
		GTLD:           "watches",
		DelegationDate: "2015-12-14",
		RemovalDate:    "",
	},
	"weather": {
		GTLD:           "weather",
		DelegationDate: "2016-01-12",
		RemovalDate:    "",
	},
	"weatherchannel": {
		GTLD:           "weatherchannel",
		DelegationDate: "2016-01-28",
		RemovalDate:    "",
	},
	"webcam": {
		GTLD:           "webcam",
		DelegationDate: "2014-03-19",
		RemovalDate:    "",
	},
	"weber": {
		GTLD:           "weber",
		DelegationDate: "2015-12-22",
		RemovalDate:    "",
	},
	"website": {
		GTLD:           "website",
		DelegationDate: "2014-05-30",
		RemovalDate:    "",
	},
	"wed": {
		GTLD:           "wed",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"wedding": {
		GTLD:           "wedding",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"weibo": {
		GTLD:           "weibo",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"weir": {
		GTLD:           "weir",
		DelegationDate: "2015-04-17",
		RemovalDate:    "",
	},
	"wf": {
		GTLD:           "wf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"whoswho": {
		GTLD:           "whoswho",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"wien": {
		GTLD:           "wien",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"wiki": {
		GTLD:           "wiki",
		DelegationDate: "2014-02-19",
		RemovalDate:    "",
	},
	"williamhill": {
		GTLD:           "williamhill",
		DelegationDate: "2014-07-27",
		RemovalDate:    "",
	},
	"win": {
		GTLD:           "win",
		DelegationDate: "2015-03-25",
		RemovalDate:    "",
	},
	"windows": {
		GTLD:           "windows",
		DelegationDate: "2015-06-10",
		RemovalDate:    "",
	},
	"wine": {
		GTLD:           "wine",
		DelegationDate: "2015-08-05",
		RemovalDate:    "",
	},
	"winners": {
		GTLD:           "winners",
		DelegationDate: "2016-07-15",
		RemovalDate:    "",
	},
	"wme": {
		GTLD:           "wme",
		DelegationDate: "2014-09-10",
		RemovalDate:    "",
	},
	"wolterskluwer": {
		GTLD:           "wolterskluwer",
		DelegationDate: "2016-02-11",
		RemovalDate:    "",
	},
	"woodside": {
		GTLD:           "woodside",
		DelegationDate: "2016-06-23",
		RemovalDate:    "",
	},
	"work": {
		GTLD:           "work",
		DelegationDate: "2014-09-23",
		RemovalDate:    "",
	},
	"works": {
		GTLD:           "works",
		DelegationDate: "2014-01-23",
		RemovalDate:    "",
	},
	"world": {
		GTLD:           "world",
		DelegationDate: "2014-09-19",
		RemovalDate:    "",
	},
	"wow": {
		GTLD:           "wow",
		DelegationDate: "2016-09-26",
		RemovalDate:    "",
	},
	"ws": {
		GTLD:           "ws",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"wtc": {
		GTLD:           "wtc",
		DelegationDate: "2014-04-29",
		RemovalDate:    "",
	},
	"wtf": {
		GTLD:           "wtf",
		DelegationDate: "2014-04-23",
		RemovalDate:    "",
	},
	"xbox": {
		GTLD:           "xbox",
		DelegationDate: "2015-06-04",
		RemovalDate:    "",
	},
	"xerox": {
		GTLD:           "xerox",
		DelegationDate: "2015-04-16",
		RemovalDate:    "",
	},
	"xfinity": {
		GTLD:           "xfinity",
		DelegationDate: "2016-07-07",
		RemovalDate:    "",
	},
	"xihuan": {
		GTLD:           "xihuan",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"xin": {
		GTLD:           "xin",
		DelegationDate: "2015-03-07",
		RemovalDate:    "",
	},
	"xn--11b4c3d": {
		GTLD:           "xn--11b4c3d",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--1ck2e1b": {
		GTLD:           "xn--1ck2e1b",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"xn--1qqw23a": {
		GTLD:           "xn--1qqw23a",
		DelegationDate: "2014-08-14",
		RemovalDate:    "",
	},
	"xn--2scrj9c": {
		GTLD:           "xn--2scrj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--30rr7y": {
		GTLD:           "xn--30rr7y",
		DelegationDate: "2015-03-31",
		RemovalDate:    "",
	},
	"xn--3bst00m": {
		GTLD:           "xn--3bst00m",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"xn--3ds443g": {
		GTLD:           "xn--3ds443g",
		DelegationDate: "2014-01-02",
		RemovalDate:    "",
	},
	"xn--3e0b707e": {
		GTLD:           "xn--3e0b707e",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--3hcrj9c": {
		GTLD:           "xn--3hcrj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--3oq18vl8pn36a": {
		GTLD:           "xn--3oq18vl8pn36a",
		DelegationDate: "2016-08-16",
		RemovalDate:    "2021-10-27",
	},
	"xn--3pxu8k": {
		GTLD:           "xn--3pxu8k",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--42c2d9a": {
		GTLD:           "xn--42c2d9a",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--45br5cyl": {
		GTLD:           "xn--45br5cyl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--45brj9c": {
		GTLD:           "xn--45brj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--45q11c": {
		GTLD:           "xn--45q11c",
		DelegationDate: "2014-11-17",
		RemovalDate:    "",
	},
	"xn--4dbrk0ce": {
		GTLD:           "xn--4dbrk0ce",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--4gbrim": {
		GTLD:           "xn--4gbrim",
		DelegationDate: "2014-05-28",
		RemovalDate:    "",
	},
	"xn--54b7fta0cc": {
		GTLD:           "xn--54b7fta0cc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--55qw42g": {
		GTLD:           "xn--55qw42g",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"xn--55qx5d": {
		GTLD:           "xn--55qx5d",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"xn--5su34j936bgsg": {
		GTLD:           "xn--5su34j936bgsg",
		DelegationDate: "2016-07-02",
		RemovalDate:    "",
	},
	"xn--5tzm5g": {
		GTLD:           "xn--5tzm5g",
		DelegationDate: "2016-04-17",
		RemovalDate:    "",
	},
	"xn--6frz82g": {
		GTLD:           "xn--6frz82g",
		DelegationDate: "2014-02-05",
		RemovalDate:    "",
	},
	"xn--6qq986b3xl": {
		GTLD:           "xn--6qq986b3xl",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"xn--80adxhks": {
		GTLD:           "xn--80adxhks",
		DelegationDate: "2014-04-24",
		RemovalDate:    "",
	},
	"xn--80ao21a": {
		GTLD:           "xn--80ao21a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--80aqecdr1a": {
		GTLD:           "xn--80aqecdr1a",
		DelegationDate: "2016-12-01",
		RemovalDate:    "",
	},
	"xn--80asehdb": {
		GTLD:           "xn--80asehdb",
		DelegationDate: "2013-10-23",
		RemovalDate:    "",
	},
	"xn--80aswg": {
		GTLD:           "xn--80aswg",
		DelegationDate: "2013-10-23",
		RemovalDate:    "",
	},
	"xn--8y0a063a": {
		GTLD:           "xn--8y0a063a",
		DelegationDate: "2016-02-06",
		RemovalDate:    "",
	},
	"xn--90a3ac": {
		GTLD:           "xn--90a3ac",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--90ae": {
		GTLD:           "xn--90ae",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--90ais": {
		GTLD:           "xn--90ais",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--9dbq2a": {
		GTLD:           "xn--9dbq2a",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--9et52u": {
		GTLD:           "xn--9et52u",
		DelegationDate: "2015-03-27",
		RemovalDate:    "",
	},
	"xn--9krt00a": {
		GTLD:           "xn--9krt00a",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"xn--b4w605ferd": {
		GTLD:           "xn--b4w605ferd",
		DelegationDate: "2015-01-24",
		RemovalDate:    "",
	},
	"xn--bck1b9a5dre4c": {
		GTLD:           "xn--bck1b9a5dre4c",
		DelegationDate: "2016-02-21",
		RemovalDate:    "",
	},
	"xn--c1avg": {
		GTLD:           "xn--c1avg",
		DelegationDate: "2014-03-05",
		RemovalDate:    "",
	},
	"xn--c2br7g": {
		GTLD:           "xn--c2br7g",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--cck2b3b": {
		GTLD:           "xn--cck2b3b",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"xn--cckwcxetd": {
		GTLD:           "xn--cckwcxetd",
		DelegationDate: "2020-06-02",
		RemovalDate:    "",
	},
	"xn--cg4bki": {
		GTLD:           "xn--cg4bki",
		DelegationDate: "2014-02-21",
		RemovalDate:    "",
	},
	"xn--clchc0ea0b2g2a9gcd": {
		GTLD:           "xn--clchc0ea0b2g2a9gcd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--czr694b": {
		GTLD:           "xn--czr694b",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"xn--czrs0t": {
		GTLD:           "xn--czrs0t",
		DelegationDate: "2014-12-06",
		RemovalDate:    "",
	},
	"xn--czru2d": {
		GTLD:           "xn--czru2d",
		DelegationDate: "2014-03-31",
		RemovalDate:    "",
	},
	"xn--d1acj3b": {
		GTLD:           "xn--d1acj3b",
		DelegationDate: "2014-02-26",
		RemovalDate:    "",
	},
	"xn--d1alf": {
		GTLD:           "xn--d1alf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--e1a4c": {
		GTLD:           "xn--e1a4c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--eckvdtc9d": {
		GTLD:           "xn--eckvdtc9d",
		DelegationDate: "2015-12-14",
		RemovalDate:    "",
	},
	"xn--efvy88h": {
		GTLD:           "xn--efvy88h",
		DelegationDate: "2015-08-24",
		RemovalDate:    "",
	},
	"xn--estv75g": {
		GTLD:           "xn--estv75g",
		DelegationDate: "2015-05-07",
		RemovalDate:    "2020-04-01",
	},
	"xn--fct429k": {
		GTLD:           "xn--fct429k",
		DelegationDate: "2016-03-25",
		RemovalDate:    "",
	},
	"xn--fhbei": {
		GTLD:           "xn--fhbei",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--fiq228c5hs": {
		GTLD:           "xn--fiq228c5hs",
		DelegationDate: "2014-01-03",
		RemovalDate:    "",
	},
	"xn--fiq64b": {
		GTLD:           "xn--fiq64b",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"xn--fiqs8s": {
		GTLD:           "xn--fiqs8s",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--fiqz9s": {
		GTLD:           "xn--fiqz9s",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--fjq720a": {
		GTLD:           "xn--fjq720a",
		DelegationDate: "2015-05-09",
		RemovalDate:    "",
	},
	"xn--flw351e": {
		GTLD:           "xn--flw351e",
		DelegationDate: "2014-11-20",
		RemovalDate:    "",
	},
	"xn--fpcrj9c3d": {
		GTLD:           "xn--fpcrj9c3d",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--fzc2c9e2c": {
		GTLD:           "xn--fzc2c9e2c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--fzys8d69uvgm": {
		GTLD:           "xn--fzys8d69uvgm",
		DelegationDate: "2016-05-11",
		RemovalDate:    "",
	},
	"xn--g2xx48c": {
		GTLD:           "xn--g2xx48c",
		DelegationDate: "2016-01-16",
		RemovalDate:    "",
	},
	"xn--gckr3f0f": {
		GTLD:           "xn--gckr3f0f",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"xn--gecrj9c": {
		GTLD:           "xn--gecrj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--gk3at1e": {
		GTLD:           "xn--gk3at1e",
		DelegationDate: "2016-09-30",
		RemovalDate:    "",
	},
	"xn--h2breg3eve": {
		GTLD:           "xn--h2breg3eve",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--h2brj9c": {
		GTLD:           "xn--h2brj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--h2brj9c8c": {
		GTLD:           "xn--h2brj9c8c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--hxt814e": {
		GTLD:           "xn--hxt814e",
		DelegationDate: "2014-12-02",
		RemovalDate:    "",
	},
	"xn--i1b6b1a6a2e": {
		GTLD:           "xn--i1b6b1a6a2e",
		DelegationDate: "2014-03-09",
		RemovalDate:    "",
	},
	"xn--imr513n": {
		GTLD:           "xn--imr513n",
		DelegationDate: "2015-05-30",
		RemovalDate:    "",
	},
	"xn--io0a7i": {
		GTLD:           "xn--io0a7i",
		DelegationDate: "2014-01-18",
		RemovalDate:    "",
	},
	"xn--j1aef": {
		GTLD:           "xn--j1aef",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--j1amh": {
		GTLD:           "xn--j1amh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--j6w193g": {
		GTLD:           "xn--j6w193g",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--jlq480n2rg": {
		GTLD:           "xn--jlq480n2rg",
		DelegationDate: "2020-06-02",
		RemovalDate:    "",
	},
	"xn--jlq61u9w7b": {
		GTLD:           "xn--jlq61u9w7b",
		DelegationDate: "2015-12-18",
		RemovalDate:    "",
	},
	"xn--jvr189m": {
		GTLD:           "xn--jvr189m",
		DelegationDate: "2016-02-22",
		RemovalDate:    "",
	},
	"xn--kcrx77d1x4a": {
		GTLD:           "xn--kcrx77d1x4a",
		DelegationDate: "2015-04-07",
		RemovalDate:    "",
	},
	"xn--kprw13d": {
		GTLD:           "xn--kprw13d",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--kpry57d": {
		GTLD:           "xn--kpry57d",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--kpu716f": {
		GTLD:           "xn--kpu716f",
		DelegationDate: "2015-12-15",
		RemovalDate:    "2020-06-26",
	},
	"xn--kput3i": {
		GTLD:           "xn--kput3i",
		DelegationDate: "2014-06-17",
		RemovalDate:    "",
	},
	"xn--l1acc": {
		GTLD:           "xn--l1acc",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--lgbbat1ad8j": {
		GTLD:           "xn--lgbbat1ad8j",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgb9awbf": {
		GTLD:           "xn--mgb9awbf",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgba3a3ejt": {
		GTLD:           "xn--mgba3a3ejt",
		DelegationDate: "2015-10-15",
		RemovalDate:    "",
	},
	"xn--mgba3a4f16a": {
		GTLD:           "xn--mgba3a4f16a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgba7c0bbn0a": {
		GTLD:           "xn--mgba7c0bbn0a",
		DelegationDate: "2016-05-03",
		RemovalDate:    "",
	},
	"xn--mgbaakc7dvf": {
		GTLD:           "xn--mgbaakc7dvf",
		DelegationDate: "2017-06-10",
		RemovalDate:    "",
	},
	"xn--mgbaam7a8h": {
		GTLD:           "xn--mgbaam7a8h",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbab2bd": {
		GTLD:           "xn--mgbab2bd",
		DelegationDate: "2014-02-18",
		RemovalDate:    "",
	},
	"xn--mgbah1a3hjkrd": {
		GTLD:           "xn--mgbah1a3hjkrd",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbai9azgqp6j": {
		GTLD:           "xn--mgbai9azgqp6j",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbayh7gpa": {
		GTLD:           "xn--mgbayh7gpa",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbb9fbpob": {
		GTLD:           "xn--mgbb9fbpob",
		DelegationDate: "2015-12-23",
		RemovalDate:    "2019-09-09",
	},
	"xn--mgbbh1a": {
		GTLD:           "xn--mgbbh1a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbbh1a71e": {
		GTLD:           "xn--mgbbh1a71e",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbc0a9azcg": {
		GTLD:           "xn--mgbc0a9azcg",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbca7dzdo": {
		GTLD:           "xn--mgbca7dzdo",
		DelegationDate: "2016-04-06",
		RemovalDate:    "",
	},
	"xn--mgbcpq6gpa1a": {
		GTLD:           "xn--mgbcpq6gpa1a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgberp4a5d4ar": {
		GTLD:           "xn--mgberp4a5d4ar",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbgu82a": {
		GTLD:           "xn--mgbgu82a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbi4ecexp": {
		GTLD:           "xn--mgbi4ecexp",
		DelegationDate: "2016-12-01",
		RemovalDate:    "",
	},
	"xn--mgbpl2fh": {
		GTLD:           "xn--mgbpl2fh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbt3dhd": {
		GTLD:           "xn--mgbt3dhd",
		DelegationDate: "2015-12-07",
		RemovalDate:    "",
	},
	"xn--mgbtx2b": {
		GTLD:           "xn--mgbtx2b",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mgbx4cd0ab": {
		GTLD:           "xn--mgbx4cd0ab",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mix891f": {
		GTLD:           "xn--mix891f",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--mk1bu44c": {
		GTLD:           "xn--mk1bu44c",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--mxtq1m": {
		GTLD:           "xn--mxtq1m",
		DelegationDate: "2015-03-03",
		RemovalDate:    "",
	},
	"xn--ngbc5azd": {
		GTLD:           "xn--ngbc5azd",
		DelegationDate: "2013-10-23",
		RemovalDate:    "",
	},
	"xn--ngbe9e0a": {
		GTLD:           "xn--ngbe9e0a",
		DelegationDate: "2015-12-15",
		RemovalDate:    "",
	},
	"xn--ngbrx": {
		GTLD:           "xn--ngbrx",
		DelegationDate: "2017-05-23",
		RemovalDate:    "",
	},
	"xn--node": {
		GTLD:           "xn--node",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--nqv7f": {
		GTLD:           "xn--nqv7f",
		DelegationDate: "2014-03-09",
		RemovalDate:    "",
	},
	"xn--nqv7fs00ema": {
		GTLD:           "xn--nqv7fs00ema",
		DelegationDate: "2014-03-09",
		RemovalDate:    "",
	},
	"xn--nyqy26a": {
		GTLD:           "xn--nyqy26a",
		DelegationDate: "2015-04-02",
		RemovalDate:    "",
	},
	"xn--o3cw4h": {
		GTLD:           "xn--o3cw4h",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--ogbpf8fl": {
		GTLD:           "xn--ogbpf8fl",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--otu796d": {
		GTLD:           "xn--otu796d",
		DelegationDate: "2018-01-24",
		RemovalDate:    "",
	},
	"xn--p1acf": {
		GTLD:           "xn--p1acf",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"xn--p1ai": {
		GTLD:           "xn--p1ai",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--pbt977c": {
		GTLD:           "xn--pbt977c",
		DelegationDate: "2015-12-15",
		RemovalDate:    "2020-06-26",
	},
	"xn--pgbs0dh": {
		GTLD:           "xn--pgbs0dh",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--pssy2u": {
		GTLD:           "xn--pssy2u",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--q7ce6a": {
		GTLD:           "xn--q7ce6a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--q9jyb4c": {
		GTLD:           "xn--q9jyb4c",
		DelegationDate: "2013-11-23",
		RemovalDate:    "",
	},
	"xn--qcka1pmc": {
		GTLD:           "xn--qcka1pmc",
		DelegationDate: "2014-11-20",
		RemovalDate:    "",
	},
	"xn--qxa6a": {
		GTLD:           "xn--qxa6a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--qxam": {
		GTLD:           "xn--qxam",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--rhqv96g": {
		GTLD:           "xn--rhqv96g",
		DelegationDate: "2014-03-12",
		RemovalDate:    "",
	},
	"xn--rovu88b": {
		GTLD:           "xn--rovu88b",
		DelegationDate: "2016-02-19",
		RemovalDate:    "",
	},
	"xn--rvc1e0am3e": {
		GTLD:           "xn--rvc1e0am3e",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--s9brj9c": {
		GTLD:           "xn--s9brj9c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--ses554g": {
		GTLD:           "xn--ses554g",
		DelegationDate: "2014-04-10",
		RemovalDate:    "",
	},
	"xn--t60b56a": {
		GTLD:           "xn--t60b56a",
		DelegationDate: "2015-07-28",
		RemovalDate:    "",
	},
	"xn--tckwe": {
		GTLD:           "xn--tckwe",
		DelegationDate: "2015-07-29",
		RemovalDate:    "",
	},
	"xn--tiq49xqyj": {
		GTLD:           "xn--tiq49xqyj",
		DelegationDate: "2016-12-01",
		RemovalDate:    "",
	},
	"xn--unup4y": {
		GTLD:           "xn--unup4y",
		DelegationDate: "2013-10-23",
		RemovalDate:    "",
	},
	"xn--vermgensberater-ctb": {
		GTLD:           "xn--vermgensberater-ctb",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"xn--vermgensberatung-pwb": {
		GTLD:           "xn--vermgensberatung-pwb",
		DelegationDate: "2014-09-27",
		RemovalDate:    "",
	},
	"xn--vhquv": {
		GTLD:           "xn--vhquv",
		DelegationDate: "2014-08-22",
		RemovalDate:    "",
	},
	"xn--vuq861b": {
		GTLD:           "xn--vuq861b",
		DelegationDate: "2015-03-18",
		RemovalDate:    "",
	},
	"xn--w4r85el8fhu5dnra": {
		GTLD:           "xn--w4r85el8fhu5dnra",
		DelegationDate: "2016-03-05",
		RemovalDate:    "",
	},
	"xn--w4rs40l": {
		GTLD:           "xn--w4rs40l",
		DelegationDate: "2016-05-16",
		RemovalDate:    "",
	},
	"xn--wgbh1c": {
		GTLD:           "xn--wgbh1c",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--wgbl6a": {
		GTLD:           "xn--wgbl6a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--xhq521b": {
		GTLD:           "xn--xhq521b",
		DelegationDate: "2014-08-14",
		RemovalDate:    "",
	},
	"xn--xkc2al3hye2a": {
		GTLD:           "xn--xkc2al3hye2a",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--xkc2dl3a5ee0h": {
		GTLD:           "xn--xkc2dl3a5ee0h",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--y9a3aq": {
		GTLD:           "xn--y9a3aq",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--yfro4i67o": {
		GTLD:           "xn--yfro4i67o",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--ygbi2ammx": {
		GTLD:           "xn--ygbi2ammx",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"xn--zfr164b": {
		GTLD:           "xn--zfr164b",
		DelegationDate: "2013-12-17",
		RemovalDate:    "",
	},
	"xperia": {
		GTLD:           "xperia",
		DelegationDate: "2015-08-05",
		RemovalDate:    "2018-07-20",
	},
	"xxx": {
		GTLD:           "xxx",
		DelegationDate: "2011-04-15",
		RemovalDate:    "",
	},
	"xyz": {
		GTLD:           "xyz",
		DelegationDate: "2014-02-19",
		RemovalDate:    "",
	},
	"yachts": {
		GTLD:           "yachts",
		DelegationDate: "2014-05-22",
		RemovalDate:    "",
	},
	"yahoo": {
		GTLD:           "yahoo",
		DelegationDate: "2016-02-13",
		RemovalDate:    "",
	},
	"yamaxun": {
		GTLD:           "yamaxun",
		DelegationDate: "2015-10-07",
		RemovalDate:    "",
	},
	"yandex": {
		GTLD:           "yandex",
		DelegationDate: "2014-07-18",
		RemovalDate:    "",
	},
	"ye": {
		GTLD:           "ye",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"yodobashi": {
		GTLD:           "yodobashi",
		DelegationDate: "2015-02-19",
		RemovalDate:    "",
	},
	"yoga": {
		GTLD:           "yoga",
		DelegationDate: "2014-10-15",
		RemovalDate:    "",
	},
	"yokohama": {
		GTLD:           "yokohama",
		DelegationDate: "2014-04-03",
		RemovalDate:    "",
	},
	"you": {
		GTLD:           "you",
		DelegationDate: "2016-03-25",
		RemovalDate:    "",
	},
	"youtube": {
		GTLD:           "youtube",
		DelegationDate: "2014-08-29",
		RemovalDate:    "",
	},
	"yt": {
		GTLD:           "yt",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"yun": {
		GTLD:           "yun",
		DelegationDate: "2016-03-30",
		RemovalDate:    "",
	},
	"za": {
		GTLD:           "za",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"zappos": {
		GTLD:           "zappos",
		DelegationDate: "2016-06-02",
		RemovalDate:    "",
	},
	"zara": {
		GTLD:           "zara",
		DelegationDate: "2015-10-27",
		RemovalDate:    "",
	},
	"zero": {
		GTLD:           "zero",
		DelegationDate: "2015-12-05",
		RemovalDate:    "",
	},
	"zip": {
		GTLD:           "zip",
		DelegationDate: "2014-09-15",
		RemovalDate:    "",
	},
	"zippo": {
		GTLD:           "zippo",
		DelegationDate: "2016-07-02",
		RemovalDate:    "2019-02-15",
	},
	"zm": {
		GTLD:           "zm",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	"zone": {
		GTLD:           "zone",
		DelegationDate: "2014-01-14",
		RemovalDate:    "",
	},
	"zuerich": {
		GTLD:           "zuerich",
		DelegationDate: "2014-12-25",
		RemovalDate:    "",
	},
	"zw": {
		GTLD:           "zw",
		DelegationDate: "1985-01-01",
		RemovalDate:    "",
	},
	// .onion is a special case and not a general gTLD. However, it is allowed in
	// some circumstances in the web PKI so the Zlint gtldMap includes it with
	// a delegationDate based on the CABF ballot to allow EV issuance for .onion
	// domains: https://cabforum.org/2015/02/18/ballot-144-validation-rules-dot-onion-names/
	"onion": {
		GTLD:           "onion",
		DelegationDate: "2015-02-18",
		RemovalDate:    "",
	},
}
